import { Ref } from 'vue';
import { default as useConfirmation } from '../../../composables/useConfirmation';
import { Agenda, AgendaGroup, AgendaItem } from '../types/agenda.type';
import { SelectCollectionContent } from '../types/common.type';
import { useContentWarning } from '../composables/content-warning.use';
import { CollectionSelectorProps } from '../../collection-selector/types/collection-selector.type';
type StorePayload = {
    initialAgenda?: Agenda;
    t: (key: string, values?: Record<string, string | number>) => string;
    confirmation: ReturnType<typeof useConfirmation>;
    selectCollectionContent: SelectCollectionContent;
    attachTo?: HTMLElement | string;
    zIndex?: number;
    openSettings?: CollectionSelectorProps['openSettings'];
};
type StoreData = {
    agenda: Ref<Agenda>;
    expandedGroups: Ref<string[]>;
    addGroup: (group?: Partial<AgendaGroup>) => AgendaGroup | undefined;
    deleteGroup: (groupId: string, groupName: string) => void;
    updateGroup: (group: Partial<Omit<AgendaGroup, 'id'>> & Pick<AgendaGroup, 'id'>) => void;
    updateGroups: (groups: AgendaGroup[]) => void;
    updateItems: (groupId: string, items: AgendaItem[]) => void;
    updateAgendaName: (name: string) => void;
    updateGroupName: (groupId: string, name: string) => void;
    deleteItem: (groupId: string, item: AgendaItem) => void;
    editItem: (groupId: string, item: AgendaItem, filters?: Record<string, any>) => Promise<void>;
    addItem: (groupId: string, filters?: Record<string, any>) => Promise<AgendaItem | undefined>;
    moveItemToGroup: (fromGroup: string, toGroup: string, item: AgendaItem) => void;
    selectCollectionContent: SelectCollectionContent;
    childModalZIndex?: number;
    contentWarning: ReturnType<typeof useContentWarning>;
};
export declare function provideAppStore({ initialAgenda, t, confirmation, selectCollectionContent, attachTo, zIndex, openSettings, }: StorePayload): StoreData;
export declare function useAppStore(): StoreData;
export {};
