import { PaginatedFolderList, Folder, FileRetrieve, FolderRetrieve, MiniFile, MiniPage, FolderFolder, File, FavoriteCreateRequest, Favorite, FolderCreateRequest, FolderUpdateRequest, FileUpdateRequest, BulkDeleteRequest, BulkDeleteResponse, FolderFile, FileStatusEnum } from '../../../../types/openapi';
import { GetFavoritesParams } from '../../../types/favorites';
import { PaginatedData } from '../../../types/paginatedData';
import { AllFileCreateRequest, DeviceFile } from '../../../types/files';
import { RecentFile } from '../../../types/recentFiles.types';
import { Mutable } from '../../../types/ts';
import { FolderListRequest } from '../../../sdk/payload.types';
type CompactFolder = Mutable<FolderFolder>;
type FolderFileWithFolder = FolderFile & {
    folder_id?: string;
} & {
    folder: {
        id: string;
        name: string;
    };
};
type FolderItemsFetcher = (folderId: Folder['id'] | undefined, options?: {
    justFetch: boolean;
    setSelectedFolder: boolean;
    forceRefresh?: boolean;
}) => Promise<FolderRetrieve>;
type FolderCreator = (payload: Omit<FolderCreateRequest, 'instance_id'>) => Promise<FolderRetrieve>;
type FolderUpdater = (payload: FolderUpdateRequest & {
    id: Folder['id'];
}) => Promise<FolderRetrieve>;
type FolderDeleter = (payload: Folder['id']) => Promise<void>;
type FolderFetcher = (payload: Folder['id']) => Promise<FolderRetrieve>;
type FoldersDeleter = (payload: BulkDeleteRequest) => Promise<BulkDeleteResponse>;
type FolderLister = (payload: FolderListRequest) => Promise<PaginatedFolderList>;
type FileCreator = (payload: Omit<AllFileCreateRequest, 'instance_id'>) => Promise<FileRetrieve>;
type FileUpdater = (payload: FileUpdateRequest & {
    id: File['id'];
}) => Promise<FileRetrieve>;
type FileOpener = (payload: {
    fileId: MiniFile['id'];
    pageIndex?: MiniPage['page_index'];
    newTab?: boolean;
}) => void;
type FileDeleter = (payload: MiniFile['id']) => Promise<MiniFile['id']>;
type FilesDeleter = (payload: BulkDeleteRequest) => Promise<BulkDeleteResponse>;
type FileFetcher = (payload: File['id']) => Promise<FileRetrieve>;
type FileListFetcher = (params?: any) => Promise<File[]>;
type FileListSearchFetcher = (params?: any) => Promise<void>;
type FilesFoldersDeleter = (payload: BulkDeleteRequest) => Promise<BulkDeleteResponse>;
type FavoriteCreator = (payload: FavoriteCreateRequest) => Promise<Favorite>;
type FavoriteDeleter = (payload: Favorite['id']) => Promise<void>;
type FavoritesDeleter = (payload: BulkDeleteRequest) => Promise<BulkDeleteResponse>;
type FavoritesFetcher = (payload?: GetFavoritesParams) => Promise<PaginatedData<Favorite>>;
type FavoritesSetter = (favorites: Favorite[]) => void;
type RecentFilesFetcher = () => Promise<RecentFile[]>;
type SelectDeviceFile = () => Promise<DeviceFile>;
type CompactFile = Pick<File, 'id' | 'name' | 'thumbnail_url' | 'tags' | 'created_by' | 'modified_at' | 'status' | 'content_type' | 'permissions'>;
type ItemsMoverItem = {
    id: File['id'] | Folder['id'];
    type: 'file' | 'folder';
};
type ItemsMover = (folderId: Folder['id'], items: ItemsMoverItem[]) => Promise<FolderRetrieve>;
declare function setFavorites(favorites: Favorite[]): void;
declare function setCurrentFolder(folderId?: FolderRetrieve['id'], folderName?: FolderRetrieve['name'], folderPath?: FolderRetrieve['path']): void;
declare function setSearchQuery(searchQuery: string): void;
declare function setIsFetchingListFiles(value: boolean): void;
declare function setSearchMetadataFilters(filters: Record<string, any>): void;
declare function setFilteredItems(items: FolderFileWithFolder[]): void;
declare function onUpsertFolder(name: string, initialName?: string): Promise<void>;
declare function clearTimeouts(): void;
declare function init({ onFolderFetch, onFolderCreate, onFolderUpdate, onFolderDelete, onFoldersDelete, onFileCreate, onFileUpdate, onFileOpen, onFileDelete, onFilesDelete, onFileFetch, onFilesList, onItemsMove, onFavoriteCreate, onFavoriteDelete, onFavoritesDelete, onFavoritesFetch, onRecentFilesFetch, onSelectDeviceFile, onFolderList, }: {
    onFolderFetch: FolderItemsFetcher;
    onFolderCreate: FolderCreator;
    onFolderUpdate: FolderUpdater;
    onFolderDelete: FolderDeleter;
    onFoldersDelete: FoldersDeleter;
    onFileCreate: FileCreator;
    onFileUpdate: FileUpdater;
    onFileOpen: FileOpener;
    onFileDelete: FileDeleter;
    onFilesDelete: FilesDeleter;
    onFileFetch: FileFetcher;
    onFilesList: FileListFetcher;
    onItemsMove: ItemsMover;
    onFavoriteCreate: FavoriteCreator;
    onFavoriteDelete: FavoriteDeleter;
    onFavoritesDelete: FavoritesDeleter;
    onFavoritesFetch: FavoritesFetcher;
    onRecentFilesFetch: RecentFilesFetcher;
    onSelectDeviceFile?: SelectDeviceFile;
    onFolderList: FolderLister;
}): void;
export type { FolderItemsFetcher, FolderCreator, FolderUpdater, FolderDeleter, FoldersDeleter, FileCreator, FileUpdater, FileOpener, FileDeleter, FilesDeleter, FileFetcher, FileListFetcher, ItemsMoverItem, ItemsMover, FavoritesFetcher, FavoriteCreator, FavoriteDeleter, FavoritesDeleter, FavoritesSetter, CompactFile, CompactFolder, RecentFilesFetcher, SelectDeviceFile, FolderLister, };
declare const _default: () => {
    state: {
        readonly fileOpener: FileOpener | null;
        readonly fileDeleter: FileDeleter | null;
        readonly filesDeleter: FilesDeleter | null;
        readonly folderItemsFetcher: FolderItemsFetcher | null;
        readonly folderCreator: FolderCreator | null;
        readonly folderUpdater: FolderUpdater | null;
        readonly folderDeleter: FolderDeleter | null;
        readonly folderFetcher: FolderFetcher | null;
        readonly foldersDeleter: FoldersDeleter | null;
        readonly fileCreator: FileCreator | null;
        readonly fileUpdater: FileUpdater | null;
        readonly fileFetcher: FileFetcher | null;
        readonly fileListFetcher: FileListSearchFetcher | null;
        readonly filesFoldersDeleter: FilesFoldersDeleter | null;
        readonly favoritesFetcher: FavoritesFetcher | null;
        readonly favoriteCreator: FavoriteCreator | null;
        readonly favoriteDeleter: FavoriteDeleter | null;
        readonly favoritesDeleter: FavoritesDeleter | null;
        readonly favoritesSetter: FavoritesSetter | null;
        readonly recentFilesFetcher: RecentFilesFetcher | null;
        readonly selectDeviceFile?: (SelectDeviceFile | null) | undefined;
        readonly itemsMover: ItemsMover | null;
        readonly folderLister: FolderLister | null;
        readonly convertingFileIdsTimeout: {
            readonly ref: () => NodeJS.Timeout;
            readonly unref: () => NodeJS.Timeout;
            readonly hasRef: () => boolean;
            readonly refresh: () => NodeJS.Timeout;
            readonly [Symbol.toPrimitive]: () => number;
            readonly [Symbol.dispose]: () => void;
        } | null;
        readonly isUpdatingFolderItems: boolean;
        readonly isFetchingFolderItems: boolean;
        readonly fetchingFolderId: Folder["id"];
        readonly isFetchingListFiles: boolean;
        readonly isFetchingSelectedFile: boolean;
        readonly isFetchingSelectedFolder: boolean;
        readonly isFetchingRecentFiles: boolean;
        readonly isFetchingFavorites: boolean;
        readonly isCreatingFavorite: boolean;
        readonly isDeletingFavorite: boolean;
        readonly folders: readonly {
            readonly id: string;
            readonly name: string;
            readonly thumbnail_url: string | null;
            readonly folders_count: number;
            readonly files_count: number;
            readonly file_thumbnail_urls: readonly string[];
            readonly canvases_count: number;
            readonly canvas_thumbnail_urls: readonly string[];
        }[];
        readonly files: readonly {
            readonly id: string;
            readonly name?: string | undefined;
            readonly tags?: readonly string[] | undefined;
            readonly thumbnail_url: string | null;
            readonly permissions?: {
                readonly can_download?: boolean | undefined;
                readonly can_share?: boolean | undefined;
            } | undefined;
            readonly content_type: import('../../../../types/openapi').FileContentTypeEnum;
            readonly status: FileStatusEnum;
            readonly created_by: {
                readonly id: number;
                readonly name: string;
                readonly email?: string | undefined;
            };
            readonly modified_at: string;
        }[];
        readonly recent: readonly {
            readonly id: string;
            readonly name?: string | undefined;
            readonly content_type: import('../../../../types/openapi').FileContentTypeEnum;
            readonly instance_id: string;
            readonly tags?: Readonly<string[] | undefined>;
            readonly thumbnail_url?: string | null | undefined;
            readonly page_index?: number | undefined;
            readonly status?: FileStatusEnum | undefined;
        }[];
        readonly selectedFile: {
            readonly id: string;
            readonly global_id: string;
            readonly name?: string | undefined;
            readonly type: import('../../../../types/openapi').FileTypeEnum;
            readonly size: number | null;
            readonly status: FileStatusEnum;
            readonly version: {
                readonly id: string;
                readonly comment: string;
                readonly created_at: string;
            };
            readonly content_type: import('../../../../types/openapi').FileContentTypeEnum;
            readonly content_extension: string | null;
            readonly content_length: number | null;
            readonly content_url: string | null;
            readonly content_thumbnails: readonly string[];
            readonly original_extension: string | null;
            readonly original_url: string | null;
            readonly thumbnail_url: string | null;
            readonly download_type?: import('../../../../types/openapi').DownloadTypeEnum | undefined;
            readonly zip_size: number | null;
            readonly zip_url: string | null;
            readonly access_type?: import('../../../../types/openapi').AccessTypeEnum | undefined;
            readonly role: import('../../../../types/openapi').CollaborationRoleEnum;
            readonly permissions?: {
                readonly can_download?: boolean | undefined;
                readonly can_share?: boolean | undefined;
            } | undefined;
            readonly pspdfkit_server_url: string | null;
            readonly pspdfkit_document_id: string | null;
            readonly pspdfkit_auth_payload: {
                readonly [x: string]: any;
            } | null;
            readonly metadata?: {
                readonly [x: string]: any;
            } | undefined;
            readonly app_metadata?: {
                readonly [x: string]: any;
            } | undefined;
            readonly tags?: readonly string[] | undefined;
            readonly transcript?: string | undefined;
            readonly search: string | null;
            readonly published_at: string | null;
            readonly expires_at?: string | null | undefined;
            readonly instance_id: string;
            readonly folder_id?: string | undefined;
            readonly folder: {
                readonly id: string;
                readonly name: string;
            };
            readonly shared_link: {
                readonly url: string;
                readonly short_url?: string | null | undefined;
            };
            readonly owned_by: {
                readonly id: number;
                readonly name: string;
                readonly email?: string | undefined;
            };
            readonly created_at: string;
            readonly created_by: {
                readonly id: number;
                readonly name: string;
                readonly email?: string | undefined;
            };
            readonly modified_at: string;
            readonly modified_by: {
                readonly id: number;
                readonly name: string;
                readonly email?: string | undefined;
            };
        } | null;
        readonly selectedFolder: {
            readonly id: string;
            readonly name: string;
            readonly content_type: string;
            readonly access_type?: import('../../../../types/openapi').AccessTypeEnum | undefined;
            readonly rules?: readonly {
                readonly field: string;
                readonly operator: import('../../../../types/openapi').OperatorEnum;
                readonly value: string;
            }[] | undefined;
            readonly owned_by: {
                readonly id: number;
                readonly name: string;
                readonly email?: string | undefined;
            };
            readonly path: readonly {
                readonly id: string;
                readonly name: string;
                readonly thumbnail_url: string | null;
                readonly folders_count: number;
                readonly files_count: number;
                readonly file_thumbnail_urls: readonly string[];
                readonly canvases_count: number;
                readonly canvas_thumbnail_urls: readonly string[];
            }[];
            readonly thumbnail_url: string | null;
            readonly folders: readonly {
                readonly id: string;
                readonly name: string;
                readonly thumbnail_url: string | null;
                readonly folders_count: number;
                readonly files_count: number;
                readonly file_thumbnail_urls: readonly string[];
                readonly canvases_count: number;
                readonly canvas_thumbnail_urls: readonly string[];
            }[];
            readonly files: readonly {
                readonly id: string;
                readonly name: string;
                readonly status: FileStatusEnum;
                readonly content_type: import('../../../../types/openapi').FileContentTypeEnum;
                readonly thumbnail_url: string;
                readonly original_url: string | null;
                readonly original_extension: string | null;
                readonly tags: readonly string[];
                readonly permissions?: {
                    readonly can_download?: boolean | undefined;
                    readonly can_share?: boolean | undefined;
                } | undefined;
                readonly metadata: {
                    readonly [x: string]: any;
                };
                readonly created_by: {
                    readonly id: number;
                    readonly name: string;
                    readonly email?: string | undefined;
                };
                readonly owned_by: {
                    readonly id: number;
                    readonly name: string;
                    readonly email?: string | undefined;
                };
                readonly modified_at: string;
                readonly expires_at: string | null;
            }[];
            readonly canvases: readonly {
                readonly id: string;
                readonly name: string;
                readonly thumbnail_url?: string | null | undefined;
                readonly tags: readonly string[];
                readonly created_by: {
                    readonly id: number;
                    readonly name: string;
                    readonly email?: string | undefined;
                };
                readonly owned_by: {
                    readonly id: number;
                    readonly name: string;
                    readonly email?: string | undefined;
                };
                readonly modified_at: string;
            }[];
            readonly created_at: string;
            readonly created_by: {
                readonly id: number;
                readonly name: string;
                readonly email?: string | undefined;
            };
            readonly modified_at: string;
            readonly modified_by: {
                readonly id: number;
                readonly name: string;
                readonly email?: string | undefined;
            };
        } | null;
        readonly favorites: {
            readonly [x: string]: {
                readonly id: string;
                readonly name: string;
                readonly thumbnail_url: string;
                readonly file: {
                    readonly id: string;
                    readonly name: string;
                    readonly content_type: string | null;
                    readonly tags: readonly string[];
                    readonly expires_at?: string | null | undefined;
                } | null;
                readonly page: {
                    readonly id: string;
                    readonly page_index?: number | undefined;
                } | null;
                readonly folder: {
                    readonly id: string;
                    readonly name: string;
                    readonly thumbnail_url: string | null;
                    readonly file_thumbnail_urls: readonly string[];
                } | null;
                readonly created_at: string;
                readonly created_by: {
                    readonly id: number;
                    readonly name: string;
                    readonly email?: string | undefined;
                };
                readonly modified_at: string;
                readonly modified_by: {
                    readonly id: number;
                    readonly name: string;
                    readonly email?: string | undefined;
                };
                readonly owned_by: {
                    readonly id: number;
                    readonly name: string;
                    readonly email?: string | undefined;
                };
            };
        };
        readonly currentFolderPath: readonly {
            readonly id: string;
            readonly name: string;
            readonly thumbnail_url: string | null;
            readonly folders_count: number;
            readonly files_count: number;
            readonly file_thumbnail_urls: readonly string[];
            readonly canvases_count: number;
            readonly canvas_thumbnail_urls: readonly string[];
        }[];
        readonly currentFolderName: Awaited<ReturnType<FolderItemsFetcher>>["name"];
        readonly currentFolderId: Awaited<ReturnType<FolderItemsFetcher>>["id"];
        readonly sectionFieldsDict: {
            readonly [x: string]: any;
        };
        readonly searchQuery: string;
        readonly searchMetadataFilters: {
            readonly [x: string]: any;
        };
        readonly filteredItems: readonly {
            readonly id: string;
            readonly name: string;
            readonly status: FileStatusEnum;
            readonly content_type: import('../../../../types/openapi').FileContentTypeEnum;
            readonly thumbnail_url: string;
            readonly original_url: string | null;
            readonly original_extension: string | null;
            readonly tags: readonly string[];
            readonly permissions?: {
                readonly can_download?: boolean | undefined;
                readonly can_share?: boolean | undefined;
            } | undefined;
            readonly metadata: {
                readonly [x: string]: any;
            };
            readonly created_by: {
                readonly id: number;
                readonly name: string;
                readonly email?: string | undefined;
            };
            readonly owned_by: {
                readonly id: number;
                readonly name: string;
                readonly email?: string | undefined;
            };
            readonly modified_at: string;
            readonly expires_at: string | null;
            readonly folder_id?: string | undefined;
            readonly folder: {
                readonly id: string;
                readonly name: string;
            };
        }[];
    };
    getters: {
        readonly sortedFiles: readonly {
            readonly id: string;
            readonly name?: string | undefined;
            readonly tags?: readonly string[] | undefined;
            readonly thumbnail_url: string | null;
            readonly permissions?: {
                readonly can_download?: boolean | undefined;
                readonly can_share?: boolean | undefined;
            } | undefined;
            readonly content_type: import('../../../../types/openapi').FileContentTypeEnum;
            readonly status: FileStatusEnum;
            readonly created_by: {
                readonly id: number;
                readonly name: string;
                readonly email?: string | undefined;
            };
            readonly modified_at: string;
        }[];
        readonly hasMetadataFilters: boolean;
        readonly isLoading: boolean;
    };
    actions: {
        init: typeof init;
        getInitialState: () => {
            fileOpener: null;
            fileDeleter: null;
            filesDeleter: null;
            folderItemsFetcher: null;
            folderCreator: null;
            folderUpdater: null;
            folderDeleter: null;
            folderFetcher: null;
            foldersDeleter: null;
            fileCreator: null;
            fileUpdater: null;
            fileFetcher: null;
            fileListFetcher: null;
            filesFoldersDeleter: null;
            favoritesFetcher: null;
            favoriteCreator: null;
            favoriteDeleter: null;
            favoritesDeleter: null;
            favoritesSetter: null;
            recentFilesFetcher: null;
            itemsMover: null;
            folderLister: null;
            convertingFileIdsTimeout: null;
            isFetchingFolderItems: boolean;
            fetchingFolderId: string;
            isUpdatingFolderItems: boolean;
            isFetchingListFiles: boolean;
            isFetchingSelectedFile: boolean;
            isFetchingSelectedFolder: boolean;
            isFetchingFavorites: boolean;
            isCreatingFavorite: boolean;
            isDeletingFavorite: boolean;
            isFetchingRecentFiles: boolean;
            folders: never[];
            files: never[];
            recent: never[];
            selectedFile: null;
            selectedFolder: null;
            favorites: {};
            currentFolderPath: never[];
            currentFolderName: string;
            currentFolderId: string;
            sectionFieldsDict: {};
            searchQuery: string;
            searchMetadataFilters: {};
            filteredItems: never[];
        };
        setFavorites: typeof setFavorites;
        setCurrentFolder: typeof setCurrentFolder;
        setSearchQuery: typeof setSearchQuery;
        setIsFetchingListFiles: typeof setIsFetchingListFiles;
        setSearchMetadataFilters: typeof setSearchMetadataFilters;
        setFilteredItems: typeof setFilteredItems;
        onUpsertFolder: typeof onUpsertFolder;
        onUploadFilesRefetchFolder: import('lodash').DebouncedFunc<() => Promise<void>>;
        clearTimeouts: typeof clearTimeouts;
        reset: () => {
            fileOpener: FileOpener | null;
            fileDeleter: FileDeleter | null;
            filesDeleter: FilesDeleter | null;
            folderItemsFetcher: FolderItemsFetcher | null;
            folderCreator: FolderCreator | null;
            folderUpdater: FolderUpdater | null;
            folderDeleter: FolderDeleter | null;
            folderFetcher: FolderFetcher | null;
            foldersDeleter: FoldersDeleter | null;
            fileCreator: FileCreator | null;
            fileUpdater: FileUpdater | null;
            fileFetcher: FileFetcher | null;
            fileListFetcher: FileListSearchFetcher | null;
            filesFoldersDeleter: FilesFoldersDeleter | null;
            favoritesFetcher: FavoritesFetcher | null;
            favoriteCreator: FavoriteCreator | null;
            favoriteDeleter: FavoriteDeleter | null;
            favoritesDeleter: FavoritesDeleter | null;
            favoritesSetter: FavoritesSetter | null;
            recentFilesFetcher: RecentFilesFetcher | null;
            selectDeviceFile?: (SelectDeviceFile | null) | undefined;
            itemsMover: ItemsMover | null;
            folderLister: FolderLister | null;
            convertingFileIdsTimeout: {
                ref: () => NodeJS.Timeout;
                unref: () => NodeJS.Timeout;
                hasRef: () => boolean;
                refresh: () => NodeJS.Timeout;
                [Symbol.toPrimitive]: () => number;
                [Symbol.dispose]: () => void;
            } | null;
            isUpdatingFolderItems: boolean;
            isFetchingFolderItems: boolean;
            fetchingFolderId: Folder["id"];
            isFetchingListFiles: boolean;
            isFetchingSelectedFile: boolean;
            isFetchingSelectedFolder: boolean;
            isFetchingRecentFiles: boolean;
            isFetchingFavorites: boolean;
            isCreatingFavorite: boolean;
            isDeletingFavorite: boolean;
            folders: {
                id: string;
                name: string;
                thumbnail_url: string | null;
                folders_count: number;
                files_count: number;
                file_thumbnail_urls: Array<string>;
                canvases_count: number;
                canvas_thumbnail_urls: Array<string>;
            }[];
            files: {
                readonly id: string;
                name?: string | undefined;
                tags?: Array<string> | undefined;
                readonly thumbnail_url: string | null;
                permissions?: {
                    can_download?: boolean | undefined;
                    can_share?: boolean | undefined;
                } | undefined;
                readonly content_type: import('../../../../types/openapi').FileContentTypeEnum;
                readonly status: FileStatusEnum;
                readonly created_by: {
                    readonly id: number;
                    readonly name: string;
                    email?: string | undefined;
                };
                readonly modified_at: string;
            }[];
            recent: {
                readonly id: string;
                name?: string | undefined;
                readonly content_type: import('../../../../types/openapi').FileContentTypeEnum;
                readonly instance_id: string;
                tags?: Readonly<string[] | undefined>;
                thumbnail_url?: string | null | undefined;
                page_index?: number | undefined;
                status?: FileStatusEnum | undefined;
            }[];
            selectedFile: {
                readonly id: string;
                readonly global_id: string;
                name?: string | undefined;
                readonly type: import('../../../../types/openapi').FileTypeEnum;
                readonly size: number | null;
                readonly status: FileStatusEnum;
                readonly version: {
                    readonly id: string;
                    readonly comment: string;
                    readonly created_at: string;
                };
                readonly content_type: import('../../../../types/openapi').FileContentTypeEnum;
                readonly content_extension: string | null;
                readonly content_length: number | null;
                readonly content_url: string | null;
                readonly content_thumbnails: Array<string>;
                readonly original_extension: string | null;
                readonly original_url: string | null;
                readonly thumbnail_url: string | null;
                download_type?: import('../../../../types/openapi').DownloadTypeEnum | undefined;
                readonly zip_size: number | null;
                readonly zip_url: string | null;
                access_type?: import('../../../../types/openapi').AccessTypeEnum | undefined;
                readonly role: import('../../../../types/openapi').CollaborationRoleEnum;
                permissions?: {
                    can_download?: boolean | undefined;
                    can_share?: boolean | undefined;
                } | undefined;
                readonly pspdfkit_server_url: string | null;
                readonly pspdfkit_document_id: string | null;
                readonly pspdfkit_auth_payload: Record<string, any> | null;
                metadata?: Record<string, any> | undefined;
                app_metadata?: Record<string, any> | undefined;
                tags?: Array<string> | undefined;
                transcript?: string | undefined;
                readonly search: string | null;
                readonly published_at: string | null;
                expires_at?: string | null | undefined;
                readonly instance_id: string;
                folder_id?: string | undefined;
                readonly folder: {
                    readonly id: string;
                    name: string;
                };
                readonly shared_link: {
                    readonly url: string;
                    short_url?: string | null | undefined;
                };
                readonly owned_by: {
                    readonly id: number;
                    readonly name: string;
                    email?: string | undefined;
                };
                readonly created_at: string;
                readonly created_by: {
                    readonly id: number;
                    readonly name: string;
                    email?: string | undefined;
                };
                readonly modified_at: string;
                readonly modified_by: {
                    readonly id: number;
                    readonly name: string;
                    email?: string | undefined;
                };
            } | null;
            selectedFolder: {
                readonly id: string;
                name: string;
                readonly content_type: string;
                access_type?: import('../../../../types/openapi').AccessTypeEnum | undefined;
                rules?: {
                    field: string;
                    operator: import('../../../../types/openapi').OperatorEnum;
                    value: string;
                }[] | undefined;
                readonly owned_by: {
                    readonly id: number;
                    readonly name: string;
                    email?: string | undefined;
                };
                readonly path: {
                    readonly id: string;
                    name: string;
                    readonly thumbnail_url: string | null;
                    readonly folders_count: number;
                    readonly files_count: number;
                    readonly file_thumbnail_urls: Array<string>;
                    readonly canvases_count: number;
                    readonly canvas_thumbnail_urls: Array<string>;
                }[];
                readonly thumbnail_url: string | null;
                readonly folders: {
                    readonly id: string;
                    name: string;
                    readonly thumbnail_url: string | null;
                    readonly folders_count: number;
                    readonly files_count: number;
                    readonly file_thumbnail_urls: Array<string>;
                    readonly canvases_count: number;
                    readonly canvas_thumbnail_urls: Array<string>;
                }[];
                readonly files: {
                    readonly id: string;
                    readonly name: string;
                    readonly status: FileStatusEnum;
                    readonly content_type: import('../../../../types/openapi').FileContentTypeEnum;
                    readonly thumbnail_url: string;
                    readonly original_url: string | null;
                    readonly original_extension: string | null;
                    readonly tags: Array<string>;
                    permissions?: {
                        can_download?: boolean | undefined;
                        can_share?: boolean | undefined;
                    } | undefined;
                    readonly metadata: Record<string, any>;
                    readonly created_by: {
                        readonly id: number;
                        readonly name: string;
                        email?: string | undefined;
                    };
                    readonly owned_by: {
                        readonly id: number;
                        readonly name: string;
                        email?: string | undefined;
                    };
                    readonly modified_at: string;
                    readonly expires_at: string | null;
                }[];
                readonly canvases: {
                    readonly id: string;
                    name: string;
                    thumbnail_url?: string | null | undefined;
                    readonly tags: Array<string>;
                    readonly created_by: {
                        readonly id: number;
                        readonly name: string;
                        email?: string | undefined;
                    };
                    readonly owned_by: {
                        readonly id: number;
                        readonly name: string;
                        email?: string | undefined;
                    };
                    readonly modified_at: string;
                }[];
                readonly created_at: string;
                readonly created_by: {
                    readonly id: number;
                    readonly name: string;
                    email?: string | undefined;
                };
                readonly modified_at: string;
                readonly modified_by: {
                    readonly id: number;
                    readonly name: string;
                    email?: string | undefined;
                };
            } | null;
            favorites: Record<MiniPage["id"] | File["id"] | Folder["id"], Favorite>;
            currentFolderPath: {
                readonly id: string;
                name: string;
                readonly thumbnail_url: string | null;
                readonly folders_count: number;
                readonly files_count: number;
                readonly file_thumbnail_urls: Array<string>;
                readonly canvases_count: number;
                readonly canvas_thumbnail_urls: Array<string>;
            }[];
            currentFolderName: Awaited<ReturnType<FolderItemsFetcher>>["name"];
            currentFolderId: Awaited<ReturnType<FolderItemsFetcher>>["id"];
            sectionFieldsDict: Record<string, any>;
            searchQuery: string;
            searchMetadataFilters: Record<string, any>;
            filteredItems: {
                readonly id: string;
                readonly name: string;
                readonly status: FileStatusEnum;
                readonly content_type: import('../../../../types/openapi').FileContentTypeEnum;
                readonly thumbnail_url: string;
                readonly original_url: string | null;
                readonly original_extension: string | null;
                readonly tags: Array<string>;
                permissions?: {
                    can_download?: boolean | undefined;
                    can_share?: boolean | undefined;
                } | undefined;
                readonly metadata: Record<string, any>;
                readonly created_by: {
                    readonly id: number;
                    readonly name: string;
                    email?: string | undefined;
                };
                readonly owned_by: {
                    readonly id: number;
                    readonly name: string;
                    email?: string | undefined;
                };
                readonly modified_at: string;
                readonly expires_at: string | null;
                folder_id?: string | undefined;
                folder: {
                    id: string;
                    name: string;
                };
            }[];
        } & {
            fileOpener: null;
            fileDeleter: null;
            filesDeleter: null;
            folderItemsFetcher: null;
            folderCreator: null;
            folderUpdater: null;
            folderDeleter: null;
            folderFetcher: null;
            foldersDeleter: null;
            fileCreator: null;
            fileUpdater: null;
            fileFetcher: null;
            fileListFetcher: null;
            filesFoldersDeleter: null;
            favoritesFetcher: null;
            favoriteCreator: null;
            favoriteDeleter: null;
            favoritesDeleter: null;
            favoritesSetter: null;
            recentFilesFetcher: null;
            itemsMover: null;
            folderLister: null;
            convertingFileIdsTimeout: null;
            isFetchingFolderItems: boolean;
            fetchingFolderId: string;
            isUpdatingFolderItems: boolean;
            isFetchingListFiles: boolean;
            isFetchingSelectedFile: boolean;
            isFetchingSelectedFolder: boolean;
            isFetchingFavorites: boolean;
            isCreatingFavorite: boolean;
            isDeletingFavorite: boolean;
            isFetchingRecentFiles: boolean;
            folders: never[];
            files: never[];
            recent: never[];
            selectedFile: null;
            selectedFolder: null;
            favorites: {};
            currentFolderPath: never[];
            currentFolderName: string;
            currentFolderId: string;
            sectionFieldsDict: {};
            searchQuery: string;
            searchMetadataFilters: {};
            filteredItems: never[];
        };
    };
};
export default _default;
