import { Ref, ComputedRef } from 'vue';
import { File, Folder, Favorite, MiniFolder } from '../../../../types/openapi';
import { RecentFile } from '../../../types/recentFiles.types';
import { ViewCompactFile, ViewCompactFileFolder, ViewCompactFolder } from '../../../types/files';
import { OrganizationSettings } from '../../../types/organizationSettings.types';
import { InstanceSettings } from '../../../types/instanceSettings.types';
export type AppName = 'admin' | 'impact';
export type AppCurrentState = 'browse' | 'create-folder' | 'upload-files' | 'update-folder' | 'update-file' | 'batch-move';
export type BrowserSectionType = 'all' | 'favorites' | 'recent' | 'trash';
export type StateSelectedItem = Partial<File | Folder | Favorite> & {
    type: string | null | undefined;
    thumbnail_url: string | null | undefined;
    content_type: string | null | undefined;
};
type SelectedItemId = Folder['id'] | File['id'] | RecentFile['id'] | (Favorite['page'] extends {
    id: any;
} ? Favorite['page']['id'] : never);
type View = 'grid' | 'table';
type RecentFileWithFavoriteId = RecentFile & {
    favoriteId: string;
};
type FavoriteExtended = Favorite & {
    favoriteId: string;
    tags?: string[];
    content_type?: string | null | undefined;
    type?: 'file' | 'folder';
};
export default function (): {
    setAppName(appName: AppName): void;
    resetSelectedItems(): void;
    removeSelectedItems(removeIds: SelectedItemId[]): void;
    selectAll(): void;
    toggleSelectAll(value: boolean): void;
    toggleItemSelection(item: StateSelectedItem, { isSelected, disableMultiple }?: {
        isSelected?: boolean;
        disableMultiple?: boolean;
    }): void;
    toggleSingleItemSelection(item: Partial<File | Folder | Favorite>): void;
    toggleItemFavorite(item: ViewCompactFileFolder & {
        favoriteId?: string;
    }): void;
    setSelectedSection(section: BrowserSectionType, folderId?: string): void;
    toggleSelectedView(): void;
    setSearch(search: string): void;
    setIsLocalSearch(isLocal: boolean): void;
    toggleContentPanel(isOpen?: boolean): void;
    selectAndOpenContentPanel(item: ViewCompactFileFolder): void;
    setCurrentState(stateName: AppCurrentState, itemId?: Folder["id"] | File["id"]): void;
    clearInlineEditingItem(): void;
    appName: Ref<AppName | "">;
    currentState: Ref<AppCurrentState>;
    selectedItemIds: Ref<SelectedItemId[]>;
    selectedSection: Ref<BrowserSectionType>;
    selectedView: Ref<View>;
    search: Ref<string>;
    displayedFiles: ComputedRef<ViewCompactFile[]>;
    displayedFolders: ComputedRef<ViewCompactFolder[]>;
    displayedFilesFolders: ComputedRef<ViewCompactFileFolder[]>;
    sortedFavorites: ComputedRef<Favorite[]>;
    displayedFavorites: ComputedRef<FavoriteExtended[]>;
    filteredRecentFiles: ComputedRef<RecentFileWithFavoriteId[]>;
    displayedRecentFiles: ComputedRef<RecentFileWithFavoriteId[]>;
    isContentPanelOpen: Ref<boolean>;
    updatingFolderId: Ref<Folder["id"] | null>;
    selectedFileId: ComputedRef<File["id"] | null>;
    selectedFolderId: ComputedRef<Folder["id"] | null>;
    updatingFolder: ComputedRef<MiniFolder | null>;
    inlineEditingItem: Ref<{
        id: string | number;
        prop: "name" | "tags";
    } | null>;
    showFilteredResults: ComputedRef<boolean>;
    isAdmin: ComputedRef<boolean>;
    enabledFavorites: ComputedRef<boolean>;
    enabledRecents: ComputedRef<boolean>;
    disabledSearchContext: ComputedRef<boolean>;
    isLocalSearch: Ref<boolean>;
    isMobileView: Ref<boolean>;
    pitcherSettings: Ref<OrganizationSettings & InstanceSettings>;
};
export {};
