import { FileTypeEnum, File, CanvasRetrieve } from '../../../../types/openapi';
import { CanvasTheme, ComponentNode, MultimediaProps } from '../types/canvas.ts';
import { CanvasThemeRetrieve, CanvasTypographyPreset, CanvasTypographyPresetId, CanvasThemeAsset } from '../../../types/canvasTheme';
import { BackgroundAttachment, BackgroundPositionX, BackgroundPositionY, BackgroundRepeat, BackgroundSize } from '../../../types/background';
export declare enum ThemeComponentOptionEnum {
    COLOR_PICKER = 0,
    PADDING = 1,
    SPACING = 2,
    HEIGHT = 3,
    BORDER_RADIUS = 4
}
export interface ThemePadding {
    top: number;
    right: number;
    bottom: number;
    left: number;
}
export interface ThemeBorderRadius {
    topLeft: number;
    topRight: number;
    bottomLeft: number;
    bottomRight: number;
}
export interface ThemeOptions {
    backgroundColor?: string;
    backgroundAttachment?: BackgroundAttachment;
    backgroundImage?: string;
    backgroundPositionX?: BackgroundPositionX;
    backgroundPositionY?: BackgroundPositionY;
    backgroundRepeat?: BackgroundRepeat;
    backgroundSize?: BackgroundSize;
    height?: string | null;
    padding?: ThemePadding;
    spacing?: number | null;
    borderRadius?: ThemeBorderRadius;
}
export interface ThemeUpdateEvents {
    onBackgroundChange: (property: string, value: any) => void;
    onHeightChange: (height?: string | null) => void;
    onPaddingChange: (padding: ThemePadding) => void;
    onMarginBottomChange: (value: number | null) => void;
    onResetSpacing: () => void;
    onBorderRadiusChange: (borderRadius: ThemeBorderRadius) => void;
}
export declare const DEFAULT_TYPOGRAPHY_STYLE: Omit<CanvasTypographyPreset, 'id'>;
declare function cleanup(): void;
declare function getDefaultTypographyConfiguration(): {
    [k: string]: {
        id: CanvasTypographyPresetId;
        font_family: string;
        font_size: string;
        font_weight: "400" | "700";
        color: string;
        line_height: string;
        letter_spacing: string;
        text_transform: "none" | "capitalize" | "lowercase" | "uppercase";
    };
};
declare function loadCustomFonts(listFiles: (params: any) => Promise<File[]>): Promise<void>;
declare function setFontAndFetchAsset(fontName?: string, url?: string): Promise<void>;
declare function applyTheme(theme: CanvasThemeRetrieve | null, legacyCanvasTheme?: Partial<CanvasTheme>): void;
declare function initializeTheme(): void;
declare function handleComponentThemeUpdate(updates: ThemeOptions, currentTheme: ThemeOptions, events: ThemeUpdateEvents): void;
declare function updateThemeProperties(theme: Partial<CanvasTheme>): void;
declare function setBackgroundImageProperties(style?: Partial<CanvasTheme['style']>): void;
declare function updateTextCSSVariables(typography: Record<string, CanvasTypographyPreset>): void;
declare function loadSectionThemes(sections: CanvasRetrieve['sections'], specificSection?: CanvasRetrieve['sections'][number]): void;
declare function loadSectionThemesAssets(sections: CanvasRetrieve['sections'], updateMultimediaNodeFn?: (nodeId: string, props: MultimediaProps, directNodeUpdate?: {
    node: ComponentNode;
    section: CanvasRetrieve['sections'][number];
}) => boolean, specificSection?: CanvasRetrieve['sections'][number]): number;
declare function clearSectionThemes(sections?: CanvasRetrieve['sections'], sectionId?: CanvasRetrieve['sections'][number]): void;
declare function removeCssUrlFunc(url: string): string;
export default function useCanvasTheme(): {
    activeTheme: import('vue').Ref<{
        id: string;
        instance_id: string;
        status: import('../../../types/canvasTheme').CanvasThemeStatus;
        is_default: boolean;
        name: string;
        created_at: string;
        modified_at: string;
        owned_by: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        };
        created_by: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        };
        modified_by?: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        } | undefined;
        logo?: {
            id: string;
            name: string;
            url: string;
        } | undefined;
        assets?: {
            id: string;
            name: string;
            url: string;
        }[] | undefined;
        settings: {
            component_spacing: number;
            background_color: string;
            palette: string[];
            assets?: {
                id: string;
                name: string;
                url: string;
            }[] | undefined;
        };
        typography: Record<string, CanvasTypographyPreset>;
        used_in_canvases_count?: number | undefined;
    } | null, CanvasThemeRetrieve | {
        id: string;
        instance_id: string;
        status: import('../../../types/canvasTheme').CanvasThemeStatus;
        is_default: boolean;
        name: string;
        created_at: string;
        modified_at: string;
        owned_by: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        };
        created_by: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        };
        modified_by?: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        } | undefined;
        logo?: {
            id: string;
            name: string;
            url: string;
        } | undefined;
        assets?: {
            id: string;
            name: string;
            url: string;
        }[] | undefined;
        settings: {
            component_spacing: number;
            background_color: string;
            palette: string[];
            assets?: {
                id: string;
                name: string;
                url: string;
            }[] | undefined;
        };
        typography: Record<string, CanvasTypographyPreset>;
        used_in_canvases_count?: number | undefined;
    } | null>;
    applyTheme: typeof applyTheme;
    canvasBgColor: import('vue').Ref<string, string>;
    clearSectionThemes: typeof clearSectionThemes;
    customFonts: import('vue').Ref<{
        readonly id: string;
        readonly global_id: string;
        name?: string | undefined;
        readonly type: FileTypeEnum;
        readonly size: number | null;
        readonly status: import('../../../../types/openapi').FileStatusEnum;
        readonly content_type: import('../../../../types/openapi').FileContentTypeEnum;
        readonly content_extension: string | null;
        readonly content_length: number | null;
        readonly content_url: string | null;
        readonly original_extension: string | null;
        readonly original_url: string | null;
        readonly thumbnail_url: string | null;
        download_type?: import('../../../../types/openapi').DownloadTypeEnum | undefined;
        readonly zip_size: number | null;
        readonly zip_url: string | null;
        access_type?: import('../../../../types/openapi').AccessTypeEnum | undefined;
        readonly role: import('../../../../types/openapi').CollaborationRoleEnum;
        permissions?: {
            can_download?: boolean | undefined;
            can_share?: boolean | undefined;
        } | undefined;
        metadata?: Record<string, any> | undefined;
        app_metadata?: Record<string, any> | undefined;
        tags?: Array<string> | undefined;
        transcript?: string | undefined;
        readonly search: string | null;
        readonly published_at: string | null;
        expires_at?: string | null | undefined;
        readonly instance_id: string;
        folder_id?: string | undefined;
        readonly folder: {
            readonly id: string;
            name: string;
        };
        readonly shared_link: {
            readonly url: string;
            short_url?: string | null | undefined;
        };
        readonly owned_by: {
            readonly id: number;
            readonly name: string;
            email?: string | undefined;
        };
        readonly created_at: string;
        readonly created_by: {
            readonly id: number;
            readonly name: string;
            email?: string | undefined;
        };
        readonly modified_at: string;
        readonly modified_by: {
            readonly id: number;
            readonly name: string;
            email?: string | undefined;
        };
    }[], File[] | {
        readonly id: string;
        readonly global_id: string;
        name?: string | undefined;
        readonly type: FileTypeEnum;
        readonly size: number | null;
        readonly status: import('../../../../types/openapi').FileStatusEnum;
        readonly content_type: import('../../../../types/openapi').FileContentTypeEnum;
        readonly content_extension: string | null;
        readonly content_length: number | null;
        readonly content_url: string | null;
        readonly original_extension: string | null;
        readonly original_url: string | null;
        readonly thumbnail_url: string | null;
        download_type?: import('../../../../types/openapi').DownloadTypeEnum | undefined;
        readonly zip_size: number | null;
        readonly zip_url: string | null;
        access_type?: import('../../../../types/openapi').AccessTypeEnum | undefined;
        readonly role: import('../../../../types/openapi').CollaborationRoleEnum;
        permissions?: {
            can_download?: boolean | undefined;
            can_share?: boolean | undefined;
        } | undefined;
        metadata?: Record<string, any> | undefined;
        app_metadata?: Record<string, any> | undefined;
        tags?: Array<string> | undefined;
        transcript?: string | undefined;
        readonly search: string | null;
        readonly published_at: string | null;
        expires_at?: string | null | undefined;
        readonly instance_id: string;
        folder_id?: string | undefined;
        readonly folder: {
            readonly id: string;
            name: string;
        };
        readonly shared_link: {
            readonly url: string;
            short_url?: string | null | undefined;
        };
        readonly owned_by: {
            readonly id: number;
            readonly name: string;
            email?: string | undefined;
        };
        readonly created_at: string;
        readonly created_by: {
            readonly id: number;
            readonly name: string;
            email?: string | undefined;
        };
        readonly modified_at: string;
        readonly modified_by: {
            readonly id: number;
            readonly name: string;
            email?: string | undefined;
        };
    }[]>;
    font: import('vue').Ref<string, string>;
    globalComponentSpacing: import('vue').Ref<number, number>;
    inheritThemeFromParent: import('vue').Ref<boolean, boolean>;
    isEditingCanvasTheme: import('vue').Ref<boolean, boolean>;
    isFluid: import('vue').Ref<boolean, boolean>;
    maintainSectionTheme: import('vue').Ref<boolean, boolean>;
    palette: import('vue').Ref<string[], string[]>;
    logo: import('vue').Ref<{
        id: string;
        name: string;
        url: string;
    } | null, CanvasThemeAsset | {
        id: string;
        name: string;
        url: string;
    } | null>;
    assets: import('vue').Ref<{
        id: string;
        name: string;
        url: string;
    }[], CanvasThemeAsset[] | {
        id: string;
        name: string;
        url: string;
    }[]>;
    typography: import('vue').Ref<Record<string, CanvasTypographyPreset>, Record<string, CanvasTypographyPreset>>;
    backgroundAttachment: import('vue').Ref<BackgroundAttachment, BackgroundAttachment>;
    backgroundImage: import('vue').Ref<string, string>;
    backgroundVideoUrl: import('vue').Ref<string, string>;
    backgroundPositionX: import('vue').Ref<BackgroundPositionX, BackgroundPositionX>;
    backgroundPositionY: import('vue').Ref<BackgroundPositionY, BackgroundPositionY>;
    backgroundSize: import('vue').Ref<BackgroundSize, BackgroundSize>;
    backgroundRepeat: import('vue').Ref<BackgroundRepeat, BackgroundRepeat>;
    isLoading: import('vue').Ref<boolean, boolean>;
    initializeTheme: typeof initializeTheme;
    getDefaultTypographyConfiguration: typeof getDefaultTypographyConfiguration;
    loadCustomFonts: typeof loadCustomFonts;
    setFontAndFetchAsset: typeof setFontAndFetchAsset;
    themes: import('vue').Ref<{
        id: string;
        instance_id: string;
        status: import('../../../types/canvasTheme').CanvasThemeStatus;
        is_default: boolean;
        name: string;
        created_at: string;
        modified_at: string;
        owned_by: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        };
        created_by: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        };
        modified_by?: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        } | undefined;
        logo?: {
            id: string;
            name: string;
            url: string;
        } | undefined;
        assets?: {
            id: string;
            name: string;
            url: string;
        }[] | undefined;
        settings: {
            component_spacing: number;
            background_color: string;
            palette: string[];
            assets?: {
                id: string;
                name: string;
                url: string;
            }[] | undefined;
        };
        typography: Record<string, CanvasTypographyPreset>;
        used_in_canvases_count?: number | undefined;
    }[], CanvasThemeRetrieve[] | {
        id: string;
        instance_id: string;
        status: import('../../../types/canvasTheme').CanvasThemeStatus;
        is_default: boolean;
        name: string;
        created_at: string;
        modified_at: string;
        owned_by: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        };
        created_by: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        };
        modified_by?: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        } | undefined;
        logo?: {
            id: string;
            name: string;
            url: string;
        } | undefined;
        assets?: {
            id: string;
            name: string;
            url: string;
        }[] | undefined;
        settings: {
            component_spacing: number;
            background_color: string;
            palette: string[];
            assets?: {
                id: string;
                name: string;
                url: string;
            }[] | undefined;
        };
        typography: Record<string, CanvasTypographyPreset>;
        used_in_canvases_count?: number | undefined;
    }[]>;
    updateTextCSSVariables: typeof updateTextCSSVariables;
    updateThemeProperties: typeof updateThemeProperties;
    loadSectionThemes: typeof loadSectionThemes;
    loadSectionThemesAssets: typeof loadSectionThemesAssets;
    removeCssUrlFunc: typeof removeCssUrlFunc;
    cleanup: typeof cleanup;
    handleComponentThemeUpdate: typeof handleComponentThemeUpdate;
    originalTheme: import('vue').Ref<{
        id: string;
        instance_id: string;
        status: import('../../../types/canvasTheme').CanvasThemeStatus;
        is_default: boolean;
        name: string;
        created_at: string;
        modified_at: string;
        owned_by: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        };
        created_by: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        };
        modified_by?: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        } | undefined;
        logo?: {
            id: string;
            name: string;
            url: string;
        } | undefined;
        assets?: {
            id: string;
            name: string;
            url: string;
        }[] | undefined;
        settings: {
            component_spacing: number;
            background_color: string;
            palette: string[];
            assets?: {
                id: string;
                name: string;
                url: string;
            }[] | undefined;
        };
        typography: Record<string, CanvasTypographyPreset>;
        used_in_canvases_count?: number | undefined;
    } | null, CanvasThemeRetrieve | {
        id: string;
        instance_id: string;
        status: import('../../../types/canvasTheme').CanvasThemeStatus;
        is_default: boolean;
        name: string;
        created_at: string;
        modified_at: string;
        owned_by: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        };
        created_by: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        };
        modified_by?: {
            readonly id: number;
            readonly name: string;
            first_name?: string | undefined;
            last_name?: string | undefined;
            readonly email: string;
            role?: import('../../../../types/openapi').UserRoleEnum | undefined;
            readonly last_login_date: string | null;
            readonly joined_date: string;
            readonly deactivated_at: string | null;
            readonly activated_at: string | null;
            readonly is_active: boolean;
            language?: import('../../../../types/openapi').LanguageEnum | undefined;
            readonly connected_services: {
                connection_id: string;
                type: string;
                name: string;
                provider: string;
                access_token?: string | undefined;
                user_id?: string | undefined;
                urls?: Record<string, string> | undefined;
            }[];
            preferred_username?: string | undefined;
            readonly picture: string | null;
            timezone?: string | undefined;
            tags?: (Array<string> | null) | undefined;
        } | undefined;
        logo?: {
            id: string;
            name: string;
            url: string;
        } | undefined;
        assets?: {
            id: string;
            name: string;
            url: string;
        }[] | undefined;
        settings: {
            component_spacing: number;
            background_color: string;
            palette: string[];
            assets?: {
                id: string;
                name: string;
                url: string;
            }[] | undefined;
        };
        typography: Record<string, CanvasTypographyPreset>;
        used_in_canvases_count?: number | undefined;
    } | null>;
    setBackgroundImageProperties: typeof setBackgroundImageProperties;
};
export {};
