import { ComponentTypes, MultimediaProps, ComponentNode, ContentGridProps, LinkProps } from '../types/canvas';
import { Selection } from '../../../types/selections';
import { FileContentTypeEnum, CanvasRetrieve, File, FileRetrieve } from '../../../../types/openapi';
import { SelectedPage, SelectedFile, SelectorType, SelectedExternalLink, SelectedAsset } from '../../content-selector/stores/app';
type ContentSelectorPayload = {
    id: ComponentNode['id'] | null;
    componentType: Extract<ComponentTypes, ComponentTypes.ContentGrid | ComponentTypes.Multimedia | ComponentTypes.Link> | null;
    selections?: Selection[];
    allowedSelectorTypes?: SelectorType[];
    allowedContentTypes?: FileContentTypeEnum[];
    allowedAssetContentTypes?: FileContentTypeEnum[];
    allowedIds?: File['id'][];
    initialMetadataFilters?: Record<string, any>;
    maxSelections?: number;
    onSelected?: (selections: (SelectedFile | SelectedPage)[]) => void;
    usedInSectionId?: CanvasRetrieve['id'];
};
type ContentSelectorState = false | ContentSelectorPayload;
declare function clearContentSelectorMode(): void;
declare function setContentSelectorMode(payload: ContentSelectorPayload): void;
export declare function prepareContentGridNodeData({ selectedItems, filesById, node, }: {
    selectedItems: (SelectedFile | SelectedPage)[];
    filesById: Record<FileRetrieve['id'], FileRetrieve>;
    node?: ComponentNode<ContentGridProps>;
}): ContentGridProps;
declare function prepareLinkNodeData({ selectedItems, filesById, node, }: {
    selectedItems: (SelectedFile | SelectedPage)[];
    filesById: Record<FileRetrieve['id'], FileRetrieve>;
    node?: ComponentNode<LinkProps>;
}): LinkProps;
declare function prepareMultimediaNodeData({ selectedItems, }: {
    selectedItems: (SelectedExternalLink | SelectedAsset)[];
}): {
    data: MultimediaProps;
    theme_meta?: Partial<ComponentNode['theme_meta']>;
} | undefined;
export default function (): {
    clearContentSelectorMode: typeof clearContentSelectorMode;
    contentSelectorMode: import('vue').Ref<false | {
        id: ComponentNode["id"] | null;
        componentType: Extract<ComponentTypes, ComponentTypes.ContentGrid | ComponentTypes.Multimedia | ComponentTypes.Link> | null;
        selections?: ({
            fileId: FileRetrieve["id"];
            type: "file" | "page";
            pageIndex?: number | undefined;
            name?: string | undefined;
            file?: {
                readonly id: string;
                name?: string | undefined;
            } | undefined;
        } | {
            url: string;
            type: "external_link";
            content_type: "video" | "image";
            from: "custom" | "pexels" | "unsplash" | "ai";
        } | {
            fileId: FileRetrieve["id"];
            type: "asset";
        })[] | undefined;
        allowedSelectorTypes?: SelectorType[] | undefined;
        allowedContentTypes?: FileContentTypeEnum[] | undefined;
        allowedAssetContentTypes?: FileContentTypeEnum[] | undefined;
        allowedIds?: File["id"][] | undefined;
        initialMetadataFilters?: Record<string, any> | undefined;
        maxSelections?: number | undefined;
        onSelected?: ((selections: (SelectedFile | SelectedPage)[]) => void) | undefined;
        usedInSectionId?: CanvasRetrieve["id"] | undefined;
    }, ContentSelectorState | {
        id: ComponentNode["id"] | null;
        componentType: Extract<ComponentTypes, ComponentTypes.ContentGrid | ComponentTypes.Multimedia | ComponentTypes.Link> | null;
        selections?: ({
            fileId: FileRetrieve["id"];
            type: "file" | "page";
            pageIndex?: number | undefined;
            name?: string | undefined;
            file?: {
                readonly id: string;
                name?: string | undefined;
            } | undefined;
        } | {
            url: string;
            type: "external_link";
            content_type: "video" | "image";
            from: "custom" | "pexels" | "unsplash" | "ai";
        } | {
            fileId: FileRetrieve["id"];
            type: "asset";
        })[] | undefined;
        allowedSelectorTypes?: SelectorType[] | undefined;
        allowedContentTypes?: FileContentTypeEnum[] | undefined;
        allowedAssetContentTypes?: FileContentTypeEnum[] | undefined;
        allowedIds?: File["id"][] | undefined;
        initialMetadataFilters?: Record<string, any> | undefined;
        maxSelections?: number | undefined;
        onSelected?: ((selections: (SelectedFile | SelectedPage)[]) => void) | undefined;
        usedInSectionId?: CanvasRetrieve["id"] | undefined;
    }>;
    setContentSelectorMode: typeof setContentSelectorMode;
    prepareContentGridNodeData: typeof prepareContentGridNodeData;
    prepareLinkNodeData: typeof prepareLinkNodeData;
    prepareMultimediaNodeData: typeof prepareMultimediaNodeData;
};
export {};
