import { MaybeRef } from '@vueuse/core';
import { Ref } from 'vue';
import { aspectRatios } from '../constants';
import { FontAwesomeType } from './font-awesome.types';
import { CollectionPlayer as CollectionPlayerProps } from '../../collection-player/types/collection-player.type';
import { FileModel } from '../../../components/CFileViewer/CFileViewer.types';
import { GetFavoritesParams } from '../../../main.lib';
import { EmbedLocation, EmbeddedLocationProperties } from '../../../types/app';
import { BackgroundSize } from '../../../types/background';
import { Call } from '../../../types/call';
import { CanvasActions } from '../../../types/canvasActions';
import { CanvasThemeAsset, CanvasThemeRetrieve, CanvasTypographyPreset } from '../../../types/canvasTheme';
import { CanvasMetadataRetrieve } from '../../../types/canvases';
import { PaginatedData } from '../../../types/paginatedData';
import { QueryOperator } from '../../../types/query-builder.types';
import { RecentFile } from '../../../types/recentFiles.types';
import { CanvasRetrieve, Favorite, File, FileContentTypeEnum, FileRetrieve, Folder, FolderRetrieve, MetadataTemplate, PatchedCanvasUpdateRequest, SharedLink, User } from '../../../../types/openapi';
import { UiSelectCollectionPlayerRequest, UiSelectCollectionPlayerResponse } from '../../../sdk/api/modules/ui/types.ui';
import { OpenExternalUrlRequestPayload, PitcherEnv } from '../../../sdk/main';
import { OpenRequestPayload } from '../../../sdk/payload.types';
type AvailableAspectRatio = (typeof aspectRatios)[number];
export declare enum HtmlLayoutTypes {
    PREVIEW = "preview",
    EDIT = "edit"
}
export declare enum ContentGridLayoutTypes {
    CAROUSEL = "carousel",
    GRID = "grid",
    LIST = "list"
}
export declare enum GridLayoutTypes {
    ONE = "one",
    TWO_EQUAL = "two-equal",
    TWO_LEFT = "two-left",
    TWO_RIGHT = "two-right",
    THREE_EQUAL = "three-equal",
    FOUR_EQUAL = "four-equal"
}
export declare enum LinkAnchorTypes {
    CANVAS_ANCHOR = "canvas-anchor",
    FILE = "file",
    WEB = "web"
}
export declare enum LinkAlignmentTypes {
    LEFT = "left",
    CENTER = "center",
    RIGHT = "right"
}
export declare enum LinkPreviewTypes {
    SOLID_BUTTON = "solid-button",
    OUTLINE_BUTTON = "outline-button",
    TEXT_LINK = "text-link"
}
export interface EmbeddableProps {
    type: 'app';
    app_name: string;
    src: string | null;
    height?: string;
    width?: string;
    embed_locations?: EmbedLocation[];
    headless_locations?: EmbedLocation[];
    properties_by_embed_location?: Partial<Record<EmbedLocation, EmbeddedLocationProperties>>;
    file: ContentGridFileProps | null;
    settings?: Record<string, unknown>;
}
export interface DynamicDatatableProperty {
    key: string;
    display_name?: string;
    sort: {
        direction?: 'asc' | 'desc';
        default?: boolean;
        enabled: boolean;
    };
    group?: boolean;
    printable?: boolean;
}
export interface DynamicDatatableFilter {
    property: string;
    operator: QueryOperator;
    value: string;
}
export interface DynamicDataTableProps {
    filters?: DynamicDatatableFilter[];
    layout: 'column' | 'row';
    page_size?: number;
    path: string;
    properties: DynamicDatatableProperty[];
    theme?: {
        background_color?: string | null;
        group_header_color?: string | null;
        font_family?: string;
    };
    break_groups_on_new_page?: boolean;
}
export interface TextProps {
    content?: string;
}
export interface BlockOverrides {
    [key: ComponentNode['id']]: {
        node_data: ComponentNode['data'];
    };
}
export interface BlockProps {
    id: CanvasRetrieve['id'];
    overrides?: BlockOverrides;
}
export interface CarouselProps {
    images?: {
        url: string;
        is_uploaded_asset?: boolean;
    }[];
    placeholder_height?: string;
    include_all_images_in_pdf?: boolean;
}
export interface CanvasFile {
    readonly name: FileModel['name'];
    readonly file_id: FileModel['id'];
    readonly content_extension: FileModel['content_extension'];
    readonly content_type: FileModel['content_type'];
    readonly content_url: FileModel['content_url'];
    readonly thumbnail_url: FileModel['thumbnail_url'];
    readonly content_length: FileModel['content_length'];
    readonly content_thumbnails: FileModel['content_thumbnails'];
    readonly pspdfkit_server_url?: FileModel['pspdfkit_server_url'];
    readonly pspdfkit_auth_payload?: FileModel['pspdfkit_auth_payload'];
}
declare const MULTIMEDIA_IMG_TYPE: {
    readonly external: "external";
    readonly pitcher_asset: "pitcher_asset";
};
export declare enum MultimediaHorizontalAlignmentOptions {
    LEFT = "left",
    CENTER = "center",
    RIGHT = "right"
}
export type ExternalMultimediaAssetType = {
    asset_type: typeof MULTIMEDIA_IMG_TYPE.external;
    external_url: string;
    type: 'image' | 'video';
    horizontal_alignment?: MultimediaHorizontalAlignmentOptions;
    from?: 'custom' | 'pexels' | 'unsplash' | 'ai';
    poster_url?: string;
    poster_background_size?: BackgroundSize;
};
export type PitcherMultimediaAssetType = {
    asset_type: typeof MULTIMEDIA_IMG_TYPE.pitcher_asset;
    file: {
        id: File['id'];
        name: File['name'];
        content_url?: File['content_url'];
    };
    type: 'image' | 'video';
    horizontal_alignment?: MultimediaHorizontalAlignmentOptions;
    poster_url?: string;
    poster_background_size?: BackgroundSize;
};
export type MultimediaProps = ExternalMultimediaAssetType | PitcherMultimediaAssetType;
export type ContentGridCommonFileProps = {
    id: FileRetrieve['id'];
    snapshot_id?: FileRetrieve['id'];
    name: FileRetrieve['name'];
    is_deleted?: boolean;
    expires_at?: FileRetrieve['expires_at'];
    content_url?: FileRetrieve['content_url'];
    content_type?: FileContentTypeEnum | null;
    content_extension?: FileRetrieve['content_extension'];
    permissions?: FileRetrieve['permissions'];
    tags?: FileRetrieve['tags'];
};
export type ContentGridFileProps = ContentGridCommonFileProps & {
    thumbnail_url?: FileRetrieve['thumbnail_url'];
    content_url: FileRetrieve['content_url'];
    content_type: FileContentTypeEnum | null;
    content_extension: FileRetrieve['content_extension'];
    readonly content_length?: FileRetrieve['content_length'];
    content_thumbnails?: FileRetrieve['content_thumbnails'] | null;
    readonly pspdfkit_server_url?: FileModel['pspdfkit_server_url'];
    readonly pspdfkit_auth_payload?: FileModel['pspdfkit_auth_payload'];
};
export type ContentGridItemFileProps = {
    file: ContentGridFileProps;
    type: 'file';
};
export type ContentGridItemSlideProps = {
    file: ContentGridCommonFileProps;
    slide: {
        index: number;
        url?: FileRetrieve['content_thumbnails'][number];
    };
    type: 'slide';
};
export interface ContentGridProps {
    items: (ContentGridItemSlideProps | ContentGridItemFileProps)[];
    size?: 'medium';
    layout_type?: ContentGridLayoutTypes;
}
export interface SectionListSection {
    id: string;
    style?: Record<string, any>;
    aspect_ratio?: AvailableAspectRatio;
    background_video_url?: string;
}
export interface SectionListProps {
    sections: SectionListSection[];
    animation_in?: string;
    selection_strategy?: 'free' | 'single' | 'at-least-one' | 'app';
    selection_app_name?: string;
    is_restricted_to_preselections?: boolean;
}
export interface GridItemTooltipProps {
    content?: string;
    content_style?: Record<string, any>;
    trigger?: string;
    trigger_style?: Record<string, any>;
}
export interface GridItemProps {
    span: number;
    tooltips?: GridItemTooltipProps[];
}
export interface GridProps {
    layout_type: GridLayoutTypes;
    columns: number;
}
export interface HtmlProps {
    html: string;
}
export interface IFrameProps {
    src: string | null;
    height?: string;
    width?: string;
    add_session_context?: boolean;
}
export type CollectionFileEntity = Pick<FileRetrieve, 'id' | 'name' | 'type' | 'tags' | 'metadata' | 'thumbnail_url' | 'permissions' | 'content_url' | 'content_type' | 'pspdfkit_auth_payload' | 'pspdfkit_document_id' | 'pspdfkit_server_url'>;
export interface LinkProps {
    alignment?: LinkAlignmentTypes;
    background_color?: string;
    canvas_anchor?: string;
    color?: string;
    display_text?: string;
    file?: (Partial<File> & {
        page_index?: number;
    }) | null;
    font_family?: string;
    font_size?: number;
    link_type?: LinkAnchorTypes;
    page_index?: number;
    preview_type?: LinkPreviewTypes;
    target?: '_self' | '_blank';
    url?: string;
}
export interface ScribbleProps {
}
export interface PageBreakProps {
}
export interface PageProps {
    aspect_ratio?: AvailableAspectRatio;
    background_video_url?: string;
}
export interface TimelineEvent {
    top_hint?: string;
    top_hint_style?: Record<string, any>;
    title?: string;
    title_style?: Record<string, any>;
    description?: string;
    description_style?: Record<string, any>;
    image_url?: string;
    image_style?: Record<string, any>;
    icon?: string;
    icon_style?: Record<string, any>;
    card_style?: Record<string, any>;
}
export interface TimelineProps {
    events: TimelineEvent[];
    layout: 'vertical' | 'horizontal';
}
type AvailableComponentProps = GridProps | GridItemProps | TextProps | CarouselProps | MultimediaProps | EmbeddableProps | ContentGridProps | SectionListProps | HtmlProps | IFrameProps | LinkProps | PageBreakProps | PageProps | TimelineProps | CollectionPlayerProps;
export interface ComponentNodeVisible {
    edit_mode: boolean;
    presentation_mode: boolean;
    pdf: boolean;
    web: boolean;
}
export interface ComponentNodeGenericThemeMeta {
    bg_color_palette_index?: number;
}
export interface ComponentNodeDynamicDataTableThemeMeta extends ComponentNodeGenericThemeMeta {
    dt_header_bg_palette_index?: number;
    dt_group_header_bg_palette_index?: number;
}
export interface ComponentNodeMultimediaThemeMeta extends ComponentNodeGenericThemeMeta {
    is_theme_logo?: boolean;
    theme_asset_index?: number;
}
export type ComponentNodeThemeMeta = ComponentNodeGenericThemeMeta | ComponentNodeDynamicDataTableThemeMeta | ComponentNodeMultimediaThemeMeta;
export interface ComponentNodeLinkable {
    linkable_in_templates: boolean;
}
export interface ComponentNodePrint {
    scale_to_fit_page?: boolean;
}
export interface ComponentNode<T = AvailableComponentProps> {
    id: string;
    type: ComponentTypes;
    tracking_id: string;
    visible?: ComponentNodeVisible;
    linkable?: ComponentNodeLinkable;
    print?: ComponentNodePrint;
    allow_admins_to_overwrite?: boolean;
    autofill?: 'off' | 'ai' | 'matching_metadata' | 'matching_tags' | 'matching_metadata_or_tags';
    autofill_content_types?: FileContentTypeEnum[] | null;
    data?: T;
    children?: ComponentNode[];
    when_used_in_section?: {
        is_editable: boolean;
        is_removable: boolean;
    };
    style?: Record<string, any>;
    tags?: string[];
    theme_meta?: ComponentNodeThemeMeta;
    height?: string;
}
export interface HomePageConfig {
    component_id: string;
    section_id?: string | null;
}
export interface CanvasContent {
    data?: ComponentNode[];
    overrides?: SectionComponentOverrides;
    home_page?: HomePageConfig;
    hidden?: {
        dsr: {
            sections: HiddenElementsInCanvas;
            components: HiddenElementsInCanvas;
        };
        dsr_print: {
            sections: HiddenElementsInCanvas;
            components: HiddenElementsInCanvas;
        };
    };
}
export interface HiddenElementsInCanvas {
    [elementId: string]: true;
}
export type SectionComponentOverride = {
    node?: ComponentNode;
    after_sibling_id?: ComponentNode['id'];
    is_removed?: true;
};
export type SectionComponentOverrides = {
    [sectionId: CanvasRetrieve['id']]: {
        [componentId: ComponentNode['id'] | 'root']: SectionComponentOverride;
    };
};
export interface ComponentMeta {
    allowedChildren: ComponentTypes[];
    defaultChildren: Partial<ComponentNode>[];
    defaultData: AvailableComponentProps;
    singleton?: boolean;
    defaultPrintable: boolean;
}
export declare enum ComponentTypes {
    Block = "Block",
    Carousel = "Carousel",
    CollectionPlayer = "CollectionPlayer",
    ContentGrid = "ContentGrid",
    DataCharts = "DataCharts",
    DynamicDataTable = "DynamicDataTable",
    Embeddable = "Embeddable",
    Grid = "Grid",
    GridItem = "GridItem",
    Html = "Html",
    IFrame = "IFrame",
    Link = "Link",
    Multimedia = "Multimedia",
    Page = "Page",
    PageBreak = "PageBreak",
    Root = "Root",
    Scribble = "Scribble",
    SectionList = "SectionList",
    Text = "Text",
    Timeline = "Timeline"
}
export declare const ComponentIcon: {
    readonly AR: "cube";
    readonly Block: "objects-column";
    readonly Carousel: "gallery-thumbnails";
    readonly Collection: "rectangle-history-circle-plus";
    readonly CollectionPlayer: "regular-rectangle-history-circle-play";
    readonly ContentGrid: "files";
    readonly DataCharts: "chart-line";
    readonly DynamicDataTable: "regular-table-circle-bolt";
    readonly Embeddable: "browser";
    readonly File: "file-circle-plus";
    readonly Grid: "table";
    readonly GridItem: "objects-column";
    readonly GridParent: "angle-down";
    readonly Html: "code";
    readonly IFrame: "window";
    readonly Link: "hand-pointer";
    readonly Multimedia: "image";
    readonly Page: "pager";
    readonly PageBreak: "arrows-from-line";
    readonly Scribble: "pen-swirl";
    readonly SectionList: "bring-forward";
    readonly Text: "text-size";
    readonly Timeline: "timeline-arrow";
    readonly Video: "video";
};
export declare const componentIconType: Record<string, FontAwesomeType>;
export type CanvasTheme = {
    background_video_url?: string;
    canvas_bg_color?: string;
    global_component_spacing?: number;
    font?: {
        name: string;
        url: string;
    };
    fluid?: boolean;
    palette?: string[];
    style?: Record<string, any>;
    typography?: Record<string, CanvasTypographyPreset>;
    aspect_ratio?: AvailableAspectRatio;
    maintain_section_theme?: boolean;
    inherit_theme_from_parent?: boolean;
    logo?: CanvasThemeAsset | null;
    assets?: CanvasThemeAsset[];
};
export declare enum CanvasBuilderMode {
    ADMIN = "admin",
    IMPACT = "impact",
    SHARING = "sharing",
    HOME = "home"
}
export interface ComponentTrackingParams {
    trackable: boolean;
}
export declare enum CanvasHistoryAction {
    ADD = "add",
    REMOVE = "remove",
    REORDER = "reorder",
    OPEN = "open",
    SAVE = "save"
}
export interface CanvasHistoryItem {
    active?: boolean;
    action: CanvasHistoryAction;
    componentType: ComponentTypes;
    icon?: string;
    id: string;
    snapshot: ComponentNode[];
    timestamp: string;
}
export interface FileProps {
    file_id: FileRetrieve['id'];
    source_file_id?: FileRetrieve['id'];
    name: FileRetrieve['name'];
    thumbnail_url?: FileRetrieve['thumbnail_url'];
    content_url: FileRetrieve['content_url'];
    content_type: FileRetrieve['content_type'];
    content_extension: FileRetrieve['content_extension'];
    content_length: FileRetrieve['content_length'];
    content_thumbnails: FileRetrieve['content_thumbnails'] | null;
    is_deleted?: boolean;
    readonly pspdfkit_server_url?: FileModel['pspdfkit_server_url'];
    readonly pspdfkit_auth_payload?: FileModel['pspdfkit_auth_payload'];
}
export type FileOpenParams = (FileProps & {
    page_index?: number;
    newTab?: boolean;
    files?: OpenRequestPayload['files'];
    used_in_section_id?: CanvasRetrieve['id'];
}) | {
    file_id: File['id'];
    name?: File['name'];
    page_index?: number;
    newTab?: boolean;
    files?: OpenRequestPayload['files'];
    used_in_section_id?: CanvasRetrieve['id'];
};
type NoCRMBuilderProps = {
    isCRM: false;
    onSfdcAccountSearch?: never;
};
export type NodeInfo = {
    id?: string;
    type: ComponentTypes;
};
export type SharingBuilderProps = NoCRMBuilderProps & {
    selectCollectionPlayerContent?: never;
    isFullscreen?: boolean;
    displayMode?: 'default' | 'print';
    startPage?: number;
    endPage?: number;
    isRedirectEvent?: never;
    mode: CanvasBuilderMode.SHARING;
    metadata: {
        baseStackingContext?: number;
    };
    activeCanvas: CanvasRetrieve;
    onExit: () => void;
    onSave?: never;
    onEnter?: () => void;
    onPageEnter?: (data: ComponentNode[], pageIndex: number) => void;
    onPageExit?: (data: ComponentNode[], pageIndex: number) => void;
    onFileEnter?: (node: NodeInfo, file: CollectionFileEntity) => void;
    onFileExit?: (node: NodeInfo, file: CollectionFileEntity) => void;
    onFilePageEnter?: (node: NodeInfo, file: CollectionFileEntity, pageIndex: number) => void;
    onFilePageExit?: (node: NodeInfo, file: CollectionFileEntity, pageIndex: number) => void;
    onCollectionPlayerContentChange?: never;
    onComponentEnter?: (data: ComponentNode | CanvasRetrieve, params: ComponentTrackingParams) => void;
    onComponentExit?: (data: ComponentNode | CanvasRetrieve, params: ComponentTrackingParams) => void;
    onAppEnter?: (data: {
        src: string;
    }) => void;
    onAppExit?: (data: {
        src: string;
    }) => void;
    onFileOpen: (file: FileOpenParams) => void;
    onOpenExternalUrl: (payload: OpenExternalUrlRequestPayload) => Promise<void>;
    deleteFile?: never;
    listFiles?: never;
    listRecommendedFiles?: never;
    listCanvases?: never;
    fetchFolder?: never;
    fetchFile?: never;
    fetchFavorites?: never;
    fetchRecentFiles?: never;
    fetchInstanceMetadataTemplate?: never;
    fetchCanvas?: (canvasId: CanvasRetrieve['id'], params?: Record<string, any>) => Promise<CanvasRetrieve>;
    renderPageAsImageUrl: (payload: {
        fileId: File['id'];
        documentId?: File['id'];
        pageIndex: number;
        params: {
            width: number;
        } | {
            height: number;
        };
    }) => Promise<ArrayBuffer>;
    getEnv: () => Promise<PitcherEnv>;
    onTrackShare?: never;
    share?: never;
    onEditMode: never;
    inCall?: never;
    myUserId?: never;
    onDownloadFile?: (file: File | ContentGridFileProps | ContentGridCommonFileProps) => Promise<void>;
    onDownloadCanvas?: (canvas: CanvasRetrieve, fileFormat?: 'pdf' | 'pptx') => Promise<void>;
    theme: CanvasThemeRetrieve | null;
    isAnyTypeOfAdmin: boolean;
    canvasMetadata: CanvasMetadataRetrieve | null;
};
export interface CRMBuilderProps {
    isCRM: true;
    onSfdcAccountSearch: (searchTerm?: MaybeRef<string>) => {
        accountsLoading: Ref<boolean>;
        accounts: Ref<{
            label: string;
            value: string;
        }[]>;
    };
}
type AdminImpactCommonBuilderProps = {
    selectCollectionPlayerContent: (payload?: UiSelectCollectionPlayerRequest) => Promise<UiSelectCollectionPlayerResponse>;
    openOnStart?: {
        component?: string;
        section?: string;
    };
    isFullscreen?: boolean;
    displayMode?: 'default' | 'print';
    startPage?: number;
    endPage?: number;
    metadata: {
        baseStackingContext?: number;
        startInMode?: CanvasActions.Present | CanvasActions.Edit;
    };
    activeCanvas: CanvasRetrieve;
    onExit: () => void;
    onEnter?: () => void;
    onComponentEnter?: (data: ComponentNode | CanvasRetrieve, params: ComponentTrackingParams) => void;
    onComponentExit?: (data: ComponentNode | CanvasRetrieve, params: ComponentTrackingParams) => void;
    onAppEnter?: (data: {
        src: string;
    }) => void;
    onAppExit?: (data: {
        src: string;
    }) => void;
    onPageEnter?: (data: ComponentNode[], pageIndex: number) => void;
    onPageExit?: (data: ComponentNode[], pageIndex: number) => void;
    onFileEnter?: (node: NodeInfo, file: CollectionFileEntity) => void;
    onFileExit?: (node: NodeInfo, file: CollectionFileEntity) => void;
    onFilePageEnter?: (node: NodeInfo, file: CollectionFileEntity, pageIndex: number) => void;
    onFilePageExit?: (node: NodeInfo, file: CollectionFileEntity, pageIndex: number) => void;
    onCollectionPlayerContentChange?: (payload: {
        componentId: string;
        uniqueFilesCount: number;
        groupsCount: number;
        slidesCount: number;
    }) => void;
    onSave: (canvasId: CanvasRetrieve['id'], canvas: PatchedCanvasUpdateRequest & {
        fields?: string;
        include_expired_files?: boolean;
    }, showToast?: boolean) => Promise<CanvasRetrieve>;
    onFileOpen: (file: FileOpenParams) => void;
    deleteFile: (fileId: FileRetrieve['id']) => Promise<string | void>;
    listFiles: (params?: any) => Promise<File[]>;
    listCanvases: (params?: any) => Promise<PaginatedData<CanvasRetrieve>>;
    fetchFolder: (folderId: Folder['id'] | undefined) => Promise<FolderRetrieve>;
    fetchFile: (fileId: FileRetrieve['id']) => Promise<FileRetrieve>;
    fetchFavorites: (payload?: GetFavoritesParams) => Promise<PaginatedData<Favorite>>;
    fetchRecentFiles: () => Promise<RecentFile[]>;
    fetchCanvas: (canvasId: CanvasRetrieve['id'], params?: Record<string, any>) => Promise<CanvasRetrieve>;
    fetchInstanceMetadataTemplate: () => Promise<MetadataTemplate>;
    renderPageAsImageUrl: (payload: {
        fileId: File['id'];
        documentId?: File['id'];
        pageIndex: number;
        params: {
            width: number;
        } | {
            height: number;
        };
    }) => Promise<ArrayBuffer>;
    getEnv?: () => Promise<PitcherEnv>;
    onEditMode?: (isEditMode: boolean) => void;
    onTrackShare?: (canvasId: CanvasRetrieve['id']) => Promise<void>;
    onOpenExternalUrl: (payload: OpenExternalUrlRequestPayload) => Promise<void>;
    share?: (canvasId: CanvasRetrieve['id']) => Promise<SharedLink>;
    isCRM: boolean;
    onDownloadFile?: (file: File | ContentGridFileProps | ContentGridCommonFileProps) => Promise<void>;
    onDownloadCanvas?: (canvas: CanvasRetrieve, fileFormat?: 'pdf' | 'pptx') => Promise<void>;
    theme: CanvasThemeRetrieve | null;
    isAnyTypeOfAdmin: boolean;
    canvasMetadata: CanvasMetadataRetrieve | null;
};
type AdminBuilderProps = AdminImpactCommonBuilderProps & (CRMBuilderProps | NoCRMBuilderProps) & {
    isRedirectEvent?: never;
    mode: CanvasBuilderMode.ADMIN;
    inCall?: never;
    myUserId?: never;
    listRecommendedFiles?: never;
};
type ImpactBuilderProps = AdminImpactCommonBuilderProps & (CRMBuilderProps | NoCRMBuilderProps) & {
    isRedirectEvent?: boolean;
    mode: CanvasBuilderMode.IMPACT;
    inCall?: boolean;
    call?: Call;
    myUserId?: User['id'];
    listRecommendedFiles: (params: {
        sectionId: CanvasRetrieve['id'];
        matchingStrategy: ('tags' | 'metadata')[];
    }) => Promise<File[]>;
};
type HomeBuilderProps = AdminImpactCommonBuilderProps & (CRMBuilderProps | NoCRMBuilderProps) & {
    isRedirectEvent?: boolean;
    mode: CanvasBuilderMode.HOME;
    inCall?: boolean;
    call?: Call;
    myUserId?: User['id'];
    listRecommendedFiles: (params: {
        sectionId: CanvasRetrieve['id'];
        matchingStrategy: ('tags' | 'metadata')[];
    }) => Promise<File[]>;
};
export type CanvasBuilderProps = AdminBuilderProps | ImpactBuilderProps | SharingBuilderProps | HomeBuilderProps;
export {};
