import { UnwrapRef } from 'vue';
import { ComponentTypes, CarouselProps, ComponentNode, ContentGridProps, EmbeddableProps, GridItemProps, GridProps, HtmlProps, IFrameProps, MultimediaProps, SectionComponentOverrides, SectionListProps, TextProps, CanvasBuilderMode, ComponentNodeVisible, LinkProps } from '../types/canvas';
import { CanvasRetrieve, FileRetrieve } from '../../../../types/openapi';
import { EmbedLocation } from '../../../types/app';
import { SectionComponentNodesBySectionId, ComponentNodesById } from '../composables/useCanvas';
import { SelectedPage, SelectedFile } from '../../content-selector/stores/app';
import { CollectionPlayer } from '../../collection-player/types/collection-player.type';
export declare function createNodeId(type?: ComponentTypes): string;
export declare function getComponentKeywords(type: ComponentTypes, t: (input: string) => string): string[];
export declare function getComponentTitle(type: ComponentTypes | string, t: (input: string) => string, options?: {
    name?: string;
}): string;
export declare function getComponentDescription(type: ComponentTypes | string, t: (input: string) => string, options?: {
    description?: string;
}): string;
export declare function getNodeDisplayNameByComponentType(node: ComponentNode | null | undefined): string;
export declare function getSectionGlobalComponentSpacing(section: CanvasRetrieve['sections'][number]): string | undefined;
export declare function discardSectionComponentOverride(sectionId: CanvasRetrieve['id'], componentId: ComponentNode['id'], overrides: SectionComponentOverrides): SectionComponentOverrides;
export declare function addCanvasComponent(currentContent: ComponentNode[], add: {
    type: ComponentTypes;
    parentId?: ComponentNode['id'] | null;
    afterSiblingId?: ComponentNode['id'] | null;
    condition?: (node: ComponentNode[]) => boolean;
    withData?: ComponentNode['data'] | null;
    withChildren?: ComponentNode['children'];
    withExtraNodeData?: Partial<ComponentNode>;
}): {
    newContent: ComponentNode<CollectionPlayer | GridProps | GridItemProps | TextProps | CarouselProps | MultimediaProps | EmbeddableProps | ContentGridProps | SectionListProps | HtmlProps | IFrameProps | LinkProps | import('../types/canvas').PageBreakProps | import('../types/canvas').PageProps | import('../types/canvas').TimelineProps>[];
    newComponentId: null;
} | {
    newContent: ComponentNode<CollectionPlayer | GridProps | GridItemProps | TextProps | CarouselProps | MultimediaProps | EmbeddableProps | ContentGridProps | SectionListProps | HtmlProps | IFrameProps | LinkProps | import('../types/canvas').PageBreakProps | import('../types/canvas').PageProps | import('../types/canvas').TimelineProps>[];
    newComponentId: string;
};
export declare function getAllPages(canvasContent: ComponentNode[], currentEmbedLocation: EmbedLocation, isEditMode?: boolean): ComponentNode<CollectionPlayer | GridProps | GridItemProps | TextProps | CarouselProps | MultimediaProps | EmbeddableProps | ContentGridProps | SectionListProps | HtmlProps | IFrameProps | LinkProps | import('../types/canvas').PageBreakProps | import('../types/canvas').PageProps | import('../types/canvas').TimelineProps>[][];
export declare function getPageQuantity(canvasContent: ComponentNode[][]): number;
export declare const getPageRange: (canvasContent: ComponentNode[], currentEmbedLocation: EmbedLocation, start?: number, end?: number) => ComponentNode[][];
export declare function scrollCanvasToTop(): void;
export declare function shouldShowEmbeddable(isEditMode: boolean, currentEmbedLocation: EmbedLocation, headlessLocations?: string[]): boolean;
export declare const isHeadlessOrNotAvailableApp: (component: ComponentNode, isEditMode: boolean, currentEmbedLocation: EmbedLocation) => boolean;
export declare function shouldDisplayPlaceholderComponent(isEditMode: boolean, mode: (typeof CanvasBuilderMode)[keyof typeof CanvasBuilderMode] | undefined, visibility?: ComponentNodeVisible): boolean;
export declare function isTextComponentEmpty(component: ComponentNode, overrides?: SectionComponentOverrides, sectionId?: CanvasRetrieve['id']): boolean;
type FoundComponent = {
    sectionId?: CanvasRetrieve['id'];
    sectionListId?: ComponentNode['id'];
    componentId: ComponentNode['id'];
} | null;
export declare function findEmbeddableInSectionsContent(canvasPages: ComponentNode[][], sectionComponentNodesBySectionId: UnwrapRef<SectionComponentNodesBySectionId>, appName: string): FoundComponent;
export declare function findAllEmbeddableTypesInCanvasContent(componentNodesById: UnwrapRef<ComponentNodesById>): Set<string>;
export declare function findEmbeddableInCanvasContent(componentNodesById: UnwrapRef<ComponentNodesById>, appName: string): FoundComponent;
export declare function scrollToComponentById(id: ComponentNode['id'] | null | undefined, instant?: boolean, delay?: number): void;
export declare function updateFirstContentGridWithShareboxItems(canvasContent: ComponentNode[], selectedItems: (SelectedFile | SelectedPage)[], filesById: Record<FileRetrieve['id'], FileRetrieve>): ComponentNode<CollectionPlayer | GridProps | GridItemProps | TextProps | CarouselProps | MultimediaProps | EmbeddableProps | ContentGridProps | SectionListProps | HtmlProps | IFrameProps | LinkProps | import('../types/canvas').PageBreakProps | import('../types/canvas').PageProps | import('../types/canvas').TimelineProps>[];
export declare function handleThemeAssetComparison(key: string | symbol | number, objValue: any, othValue: any, object: any, other: any, fileProps: string[], isEqual: (obj1: any, obj2: any) => boolean, componentsWithThemeMeta?: Set<string>): boolean | undefined;
export declare function applyCanvasThemeAssetsToNode(node: ComponentNode): ComponentNode;
export declare function processCanvasForSectionThemeOverride(canvas: CanvasRetrieve, maintainSectionTheme: boolean): CanvasRetrieve;
export {};
