import { EmitFn, Ref, ComputedRef } from 'vue';
import { CollectionGroup, CollectionPlayer, CollectionSlide } from '../types/collection-player.type';
import { default as Swiper } from 'swiper';
import { File } from '../../../../types/openapi';
import { default as useZoom } from '../composables/zoom.use';
import { default as useNewZoom } from '../composables/new-zoom.use';
import { default as useFullscreen } from '../composables/fullscreen.use';
import { CollectionFileEntity, NodeInfo } from '../../canvas-builder/types/canvas';
import { ActionCallback, default as useKeyboardBindings } from '../composables/keyboard-bindings.use';
import { default as useSlideDirection } from '../composables/slide-direction.use';
import { useCacheNavigation } from '../composables/navigation-cache.use';
import { useAnnotationLayer } from '../composables/annotation-layer.use';
export type RenderPageAsImage = (payload: {
    fileId: File['id'];
    documentId?: File['id'];
    pageIndex: number;
    params: {
        width: number;
    } | {
        height: number;
    };
}) => Promise<ArrayBuffer>;
export type Api = {
    renderPageAsImage: RenderPageAsImage;
    onFileEnter?: (node: NodeInfo, file: CollectionFileEntity) => void;
    onFileExit?: (node: NodeInfo, file: CollectionFileEntity) => void;
    onFilePageEnter?: (node: NodeInfo, file: CollectionFileEntity, pageIndex: number) => void;
    onFilePageExit?: (node: NodeInfo, file: CollectionFileEntity, pageIndex: number) => void;
};
export type Options = {
    videoStartTime?: number;
};
export type Emit = {
    close: [];
    click: [event: MouseEvent];
};
type StorePayload = {
    isLoading: Ref<boolean>;
    inModal: Ref<boolean>;
    isEditMode: Ref<boolean>;
    data: Ref<CollectionPlayer>;
    rootElement: Ref<HTMLElement | null>;
    api: Api;
    emit: EmitFn<Emit>;
    options?: Options;
    nodeId?: string;
};
type StoreData = {
    isLoading: Ref<boolean>;
    inModal: Ref<boolean>;
    fitToWidth: Ref<boolean>;
    isEditMode: Ref<boolean>;
    isOpenTableOfContents: Ref<boolean>;
    swiperElement: Ref<(HTMLElement & {
        swiper: Swiper;
    }) | null>;
    zoom: ReturnType<typeof useZoom | typeof useNewZoom>;
    fullscreen: ReturnType<typeof useFullscreen>;
    data: Ref<CollectionPlayer>;
    visibleGroups: ComputedRef<CollectionGroup[]>;
    hasManyGroups: ComputedRef<boolean>;
    activeSlide: Ref<CollectionSlide | null>;
    activeGroup: Ref<CollectionGroup | null>;
    setActiveSlide: (group?: CollectionGroup, slide?: CollectionSlide) => void;
    onSlideChange: (customEvent: CustomEvent<[swiper: Swiper]>) => void;
    activatePreviousGroup: () => void;
    activateNextGroup: () => void;
    toggleTableOfContents: () => void;
    toggleFitToWidth: () => void;
    allowTouchMove: (value: boolean) => void;
    isSwiperVisible: Ref<boolean>;
    setSwiperVisibility: (isVisible: boolean) => void;
    api: Api;
    keyboardBindings: ReturnType<typeof useKeyboardBindings>;
    slideDirection: ReturnType<typeof useSlideDirection>;
    closeApp: () => void;
    options?: Options;
    cacheNavigation: ReturnType<typeof useCacheNavigation>;
    nodeId?: string;
    handleKeyAction: ActionCallback;
    annotationLayer: ReturnType<typeof useAnnotationLayer>;
};
export declare function provideAppStore({ data, isEditMode, rootElement, api, emit, options, isLoading, nodeId, inModal, }: StorePayload): StoreData;
export declare function useAppStore(): StoreData;
export {};
