import { Ref, EmitFn, ComputedRef, ComponentPublicInstance } from 'vue';
import { default as useConfirmation } from '../../../composables/useConfirmation';
import { CollectionGroup, CollectionPlayer, CollectionSlide } from '../../collection-player/types/collection-player.type';
import { FetchFileList, SelectFileContent } from '../types/common.type';
import { File, FileRetrieve } from '../../../../types/openapi';
import { Translations } from '../types/collection-selector.type';
import { Emit } from '../App.vue';
import { useContentWarning } from '../composables/content-warning.use';
type StorePayload = {
    initialCollection?: CollectionPlayer;
    t: (key: string, values?: Record<string, string | number>) => string;
    confirmation: ReturnType<typeof useConfirmation>;
    selectFileContent: SelectFileContent;
    attachTo?: HTMLElement | string;
    openSettings?: () => void;
    closeOnSettings?: boolean;
    fetchFile: (id: string) => Promise<FileRetrieve>;
    fetchFileList: FetchFileList;
    zIndex?: number;
    emit: EmitFn<Emit>;
    translations?: Translations;
    contentRef: Ref<ComponentPublicInstance | null>;
};
type StoreData = {
    collection: Ref<CollectionPlayer>;
    expandedGroups: Ref<string[]>;
    usedFiles: Ref<Record<File['id'], File>>;
    addGroup: (group?: Partial<CollectionGroup>) => CollectionGroup | undefined;
    deleteGroup: (groupId: string, groupName: string) => void;
    updateGroup: (group: Partial<Omit<CollectionGroup, 'id'>> & Pick<CollectionGroup, 'id'>) => void;
    updateGroups: (groups: CollectionGroup[]) => void;
    updateSlides: (groupId: string, slides: CollectionSlide[]) => void;
    updateCollectionName: (name: string) => void;
    updateGroupName: (groupId: string, name: string) => void;
    deleteSlide: (groupId: string, slide: CollectionSlide) => void;
    addSlides: (groupId: string, filters?: Record<string, any>) => Promise<CollectionSlide[] | undefined>;
    moveSlideToGroup: (fromGroup: string, toGroup: string, slide: CollectionSlide) => void;
    selectFileContent: SelectFileContent;
    openSettings: () => void;
    closeOnSettings?: boolean;
    fetchFile: (id: string) => Promise<FileRetrieve>;
    fetchFileList: FetchFileList;
    childModalZIndex?: number;
    cancel: () => void;
    saveAndClose: () => void;
    translations?: Translations;
    isSettingsButtonVisible: ComputedRef<boolean>;
    contentWarning: ReturnType<typeof useContentWarning>;
};
export declare function provideAppStore({ initialCollection, t, confirmation, selectFileContent, attachTo, openSettings: openSettingsFn, closeOnSettings, fetchFile, fetchFileList, zIndex, emit, translations, contentRef, }: StorePayload): StoreData;
export declare function useAppStore(): StoreData;
export {};
