import { Ref, ComputedRef } from 'vue';
import { I18n } from 'vue-i18n';
import { Instance, AnnotationsUnion } from 'pspdfkit';
import { AnnotationType } from '../CFileViewer.types';
import { PitcherFile } from '../../../types/file.types';
import { Favorite, MiniPage, File, FileRetrieve } from '../../../../types/openapi';
import { CLIENT_TYPE } from '../../../constants/cdp.const';
import { default as CFileViewerBottomPdf } from './CFileViewerBottom.pdf.vue';
import { CanvasFile } from '../../../apps/canvas-builder/types/canvas';
import { SupportedLocale } from '../../../types/i18n.types';
import { OrganizationSettings } from '../../../types/organizationSettings.types';
import { InstanceSettings } from '../../../types/instanceSettings.types';
import { LaunchDarklyEnv } from '../../../types/launchDarkly.types';
import { SaveLinkAnnotationPayload } from './CFileViewer.pdf.link.types';
declare const fileViewerSettings: Readonly<Ref<{
    readonly fitMode: "width" | "viewport";
}, {
    readonly fitMode: "width" | "viewport";
}>>;
interface FileViewerActions {
    onCloseFile: () => void;
    onToggleFavoriteFilePage: (pageIndex: number) => void;
    onShowPageMetadata: (pageIndex: number) => void;
}
interface FileViewerPdfReturnType {
    viewPdf: (file: PitcherFile | CanvasFile | null, pageIndex: MiniPage['page_index']) => Promise<Instance | void>;
    onPdfFullscreen: (force?: boolean) => void;
    updateFileViewerSettings: (settings: Partial<typeof fileViewerSettings.value>) => void;
    cleanupPspdfKit: () => void;
    resetAnnotationChanges: () => void;
    isSearchOpen: Ref<boolean>;
    isThumbnailsOpen: Ref<boolean>;
    isTextAnnotationOpen: Ref<boolean>;
    isLinkAnnotationOpen: Ref<boolean>;
    currentPageIndex: Ref<number>;
    toggleFavoritePageIndex: Ref<number | null>;
    isAnnotationOpen: Ref<boolean>;
    areAnnotationsModified: Ref<boolean>;
    selectedAnnotationType: Ref<Exclude<AnnotationType, 'text'>>;
    isSwitchingInteractionMode: Ref<boolean>;
    fileViewerSettings: typeof fileViewerSettings;
    isFullscreen: Ref<boolean>;
    currentLinkAnnotation: Ref<AnnotationsUnion | null>;
    showLinkAnnotationPopover: ComputedRef<boolean>;
    onToggleLinkAnnotation: () => void;
    onCloseLinkAnnotationPopover: () => void;
    onSaveLinkAnnotation: (data: SaveLinkAnnotationPayload) => void;
    hasHotspotsOnCurrentPage: Ref<boolean>;
}
declare const _default: ({ pdfViewerEl, bottomBarRef, i18n, appLocale, actions, filePagesFavorites, assetsPrefix, isFavoriteEnabled, clientType, context, pitcherSettings, launchDarkly, emit, fileId, fetchFileById, }: {
    pdfViewerEl: Ref<HTMLElement | null>;
    bottomBarRef: Ref<InstanceType<typeof CFileViewerBottomPdf> | null>;
    filePagesFavorites: ComputedRef<Favorite[] | null>;
    i18n: I18n;
    appLocale?: SupportedLocale;
    actions: FileViewerActions;
    assetsPrefix: string;
    isFavoriteEnabled: boolean;
    clientType: (typeof CLIENT_TYPE)[keyof typeof CLIENT_TYPE];
    context?: Record<string, any>;
    pitcherSettings?: ComputedRef<OrganizationSettings & InstanceSettings>;
    launchDarkly: ComputedRef<LaunchDarklyEnv>;
    fileId: ComputedRef<File["id"] | undefined>;
    emit: (name: string, ...args: any[]) => void;
    fetchFileById?: (id: FileRetrieve["id"]) => Promise<FileRetrieve>;
}) => FileViewerPdfReturnType;
export default _default;
