import { Ref, ComputedRef } from 'vue';
import { GetInstanceMetadataTemplatesPayload } from '../../sdk/payload.types';
import { CanvasType } from '../../types/canvases';
import { PaginatedMetadataTemplateList, CanvasRetrieve, PatchedCanvasUpdateRequest } from '../../../types/openapi';
interface BaseBulkProps {
    selectedRows: Ref<Record<string, boolean>>;
    title?: string;
    onComplete: () => void | Promise<void>;
    confirmText?: string;
    cancelText?: string;
}
interface BulkUpdateFileAttributeProps extends BaseBulkProps {
    fileNames: string[];
    metadataFetcher?: (params?: GetInstanceMetadataTemplatesPayload) => Promise<PaginatedMetadataTemplateList>;
    noMetadataErrorText?: string;
    subtitle?: string;
    isBulkUpdating: Ref<boolean>;
}
interface BulkUpdateMetadataDialogProps extends BaseBulkProps {
    selectedItemNames?: string[];
    metadataFetcher?: (params?: GetInstanceMetadataTemplatesPayload) => Promise<PaginatedMetadataTemplateList>;
    noMetadataErrorText?: string;
    subtitle?: string;
    isBulkUpdating: Ref<boolean>;
    canvasType: CanvasType;
    updater?: (params: PatchedCanvasUpdateRequest & {
        id: CanvasRetrieve['id'];
        fields?: string;
    }) => Promise<CanvasRetrieve>;
}
interface BulkDeleteDialogProps extends BaseBulkProps {
    filteredData: ComputedRef<CanvasRetrieve[]>;
    isBulkDeleting: Ref<boolean>;
    canvasType: CanvasType;
    isReadonly?: (canvas: CanvasRetrieve) => boolean;
    content?: string;
}
interface BulkTagsProps extends BaseBulkProps {
    filteredData: ComputedRef<CanvasRetrieve[]>;
    isBulkUpdating: Ref<boolean>;
    canvasType: CanvasType;
    isReadonly?: (canvas: CanvasRetrieve) => boolean;
    content?: string;
}
export default function useCanvasesManagementBulk(): {
    bulkDeleteDialog: ({ filteredData, selectedRows, isBulkDeleting, canvasType, onComplete, isReadonly, title, content, confirmText, cancelText, }: BulkDeleteDialogProps) => Promise<void>;
    bulkUpdateMetadataDialog: ({ selectedRows, selectedItemNames, metadataFetcher, noMetadataErrorText, title, subtitle, isBulkUpdating, onComplete, confirmText, cancelText, canvasType, updater, }: BulkUpdateMetadataDialogProps) => Promise<void>;
    bulkUpdateFileAttributes: ({ selectedRows, fileNames, metadataFetcher, noMetadataErrorText, title, subtitle, isBulkUpdating, onComplete, confirmText, cancelText, }: BulkUpdateFileAttributeProps) => Promise<void>;
    bulkAddTagsDialog: ({ filteredData, selectedRows, isBulkUpdating, canvasType, onComplete, isReadonly, title, confirmText, cancelText, }: BulkTagsProps) => Promise<void>;
    bulkRemoveTagsDialog: ({ filteredData, selectedRows, isBulkUpdating, canvasType, onComplete, isReadonly, title, confirmText, cancelText, }: BulkTagsProps) => Promise<void>;
    bulkUpdateDistributionDialog: ({ selectedCount, isBulkUpdating, canvasType, selectedRows, onComplete, title, confirmText, cancelText, }: {
        selectedCount: number;
        isBulkUpdating: Ref<boolean>;
        canvasType: CanvasType;
        selectedRows: Ref<Record<string, boolean>>;
        onComplete: () => void | Promise<void>;
        title?: string;
        confirmText?: string;
        cancelText?: string;
    }) => Promise<void>;
    bulkUpdateFileDistributionDialog: ({ selectedCount, isBulkUpdating, selectedRows, onComplete, title, confirmText, cancelText, }: {
        selectedCount: number;
        isBulkUpdating: Ref<boolean>;
        selectedRows: Ref<Record<string, boolean>>;
        onComplete: () => void | Promise<void>;
        title?: string;
        confirmText?: string;
        cancelText?: string;
    }) => Promise<void>;
};
export {};
