import { Ref } from 'vue';
import { LocationRoute, LocationRoutes, UpdateLocationPitcherEvent } from '../sdk/interfaces';
import { default as useLocationAPI } from './useLocationAPI';
interface UseLocationManipulation {
    routes: LocationRoutes;
    relations: {
        [key: string]: string;
    };
    app: string;
    actionsQueue: Ref<UpdateLocationPitcherEvent[]>;
}
type LocationQuery = Record<string, any>;
export interface RegisterLocation {
    child_app: string;
    parent_app?: string;
    path?: string;
    query?: LocationQuery;
}
interface Route {
    path: string;
    query: LocationQuery;
}
export default function useLocationManipulation({ routes, relations, app, actionsQueue }: UseLocationManipulation): {
    isPathRestored: Ref<boolean, boolean>;
    isAppMounted: import('vue').ComputedRef<boolean>;
    isAppRestored: import('vue').ComputedRef<boolean>;
    recoverRouteFromLocations: (rootApp: string) => Route;
    isSameRoute: (route1?: Route, route2?: Route) => boolean;
    isSameRouteAsStored: (internalRouter: ReturnType<typeof useLocationAPI>["internalRouter"]) => boolean;
    deleteRelation: (appName: string) => string[];
    addActionToQueue: (body: UpdateLocationPitcherEvent) => void;
    registerLocation: ({ child_app, parent_app, path, query }: RegisterLocation) => void;
    createRoute: (params?: Partial<LocationRoute>) => LocationRoute;
    unregisterLocation: (appName: string) => void;
};
export {};
