import { AdminSelectAgendaRequest, AdminSelectAgendaResponse, AdminSelectCollectionPlayerRequest, AdminSelectCollectionPlayerResponse, AdminSelectContentRequest, AdminSelectContentResponse } from './types.admin';
/**
 * Opens the collection player selector modal to allow the user to select collection player content and handle the outcome.
 * ```
 * const api = useApi() // or useAdmin() if you know that you 're in Admin context
 *
 * adminApi.selectCollectionContent({
 *  // optional payload
 *  initial_data: {
 *   name: 'test',
 *   groups: []
 *  }
 * })
 * ```
 */
export declare function selectCollectionContent(payload?: AdminSelectCollectionPlayerRequest): Promise<AdminSelectCollectionPlayerResponse>;
/**
 * Opens the agenda selector modal to allow the user to select agenda content and handle the outcome.
 * ```
 * const api = useApi() // or useAdmin() if you know that you 're in Admin context
 *
 * adminApi.selectAgendaContent({
 *  // optional payload
 *  initial_agenda: {
 *   name: 'test',
 *   groups: []
 *  }
 * })
 * ```
 */
export declare function selectAgendaContent(payload?: AdminSelectAgendaRequest): Promise<AdminSelectAgendaResponse>;
/**
 * Opens a selector that allows you to select (and preselect) from your Pitcher uploaded content.
 *
 * @example
 * const api = useApi() // or useAdmin() if you know that you 're in Admin app context
 * api
 *   .select_content({
 *     selections: [
 *       { fileId: "01HCZ623YYRFJQ0F7B69VWE510", type: "file" },
 *       {
 *         fileId: "01HD3XGZ5FN90QJGK7CH8TBZDF",
 *         type: "page",
 *         pageIndex: 2,
 *       },
 *     ],
 *   })
 */
export declare function selectContent(payload: AdminSelectContentRequest): Promise<AdminSelectContentResponse>;
