import { File, PaginatedFileList } from '../../../../../types/openapi';
/**
 * Get the metadata object of an app with a given name.
 *
 * @param {object} payload - The payload object.
 * @param {string} payload.app_name - `name` value from `app.json` of the app you want to get the metadata of.
 *
 * @example
 * useAdmin().getAppConfig({ app_name: 'my-app' })
 */
export declare function getAppConfig(payload: {
    app_name: string;
}): Promise<Record<string, any>>;
/**
 * Fetches a file by ID.
 *
 * @example
 * adminApi.getFile({ id: 'my-file-id' })
 */
export declare function getFile(payload: {
    id: File['id'];
}): Promise<File>;
/**
 * Lists available files.
 *
 * @example
 * adminApi.getFiles()
 */
export declare function getFiles(payload: Record<string, any>): Promise<PaginatedFileList>;
/**
 * Opens a file by id.
 *
 * @example
 * adminApi.open({ id: 'my-file-id' })
 */
export declare function open(payload: {
    id: File['id'];
}): Promise<void>;
/**
 * Closes the already open file that was opened via api or by the user.
 *
 * @example
 * adminApi.close()
 */
export declare function close(): Promise<void>;
