import { AdminToastRequest, ADMIN_MESSAGE_TYPES, AdminMessagePayloads } from './types.admin';
/**
 * Subscribe to a given event type by its key.
 *
 * @param type The event type/key to subscribe to.
 * @param handler The handler function to call when the event is emitted.
 * @returns A Promise resolving to a cleanup function to unsubscribe from the event.
 */
declare function on(type: (typeof ADMIN_MESSAGE_TYPES)[keyof typeof ADMIN_MESSAGE_TYPES], handler: (data: AdminMessagePayloads[typeof type]) => Promise<void>): Promise<() => void>;
/**
 * Show a toast message to the user. Compatible with the UI API version of this method.
 *
 * @example
 * useAdmin().toast({ type: 'info', message: 'Hello, world!' })
 */
declare function toast(payload: AdminToastRequest): Promise<void>;
declare const _default: {
    getUsers(payload?: import('../../../../main.lib').GetUsersParams): Promise<import('../../../../main.lib').PaginatedData<import('../../../../main.lib').User>>;
    getAppConfig(payload: {
        app_name: string;
    }): Promise<Record<string, any>>;
    getFile(payload: {
        id: import('../../../../main.lib').File["id"];
    }): Promise<import('../../../../main.lib').File>;
    getFiles(payload: Record<string, any>): Promise<import('../../../../main.lib').PaginatedFileList>;
    open(payload: {
        id: import('../../../../main.lib').File["id"];
    }): Promise<void>;
    close(): Promise<void>;
    getInstanceMetadataTemplates(payload?: import('../../../payload.types').GetInstanceMetadataTemplatesPayload): Promise<import('../../../../main.lib').PaginatedMetadataTemplateList>;
    createCanvas(payload: import('../../../../main.lib').CanvasCreateRequest): Promise<import('../../../../main.lib').CanvasRetrieve>;
    getCanvases(payload: import('../../../../main.lib').GetCanvasesParams & {
        filters?: Record<string, any>;
        fields?: string;
    }): Promise<import('../../../../main.lib').PaginatedData<import('../../../../main.lib').CanvasRetrieve>>;
    getCanvas(payload: {
        id: import('../../../../main.lib').CanvasRetrieve["id"];
        fields?: string;
    }): Promise<import('../../../../main.lib').CanvasRetrieve>;
    updateCanvas(payload: import('../../../../main.lib').PatchedCanvasUpdateRequest & {
        id: import('../../../../main.lib').CanvasRetrieve["id"];
        instance_id?: import('../../../../main.lib').Instance["id"];
        fields?: string;
    }): Promise<import('../../../../main.lib').CanvasRetrieve>;
    openCanvasOverlay(payload: {
        id: import('../../../../main.lib').CanvasRetrieve["id"];
        edit_mode?: boolean;
        fullscreen?: boolean;
        component_id?: string;
        section_id?: string;
        position?: {
            left?: number | string;
            right?: number | string;
            top?: number | string;
            bottom?: number | string;
        };
    }): Promise<void>;
    selectCanvases(payload?: import('./types.admin').AdminSelectCanvasesRequest): Promise<import('./types.admin').AdminSelectCanvasesResponse>;
    getEnv(): Promise<import('./types.admin').AdminEnv>;
    selectCollectionContent(payload?: import('./types.admin').AdminSelectCollectionPlayerRequest): Promise<import('./types.admin').AdminSelectCollectionPlayerResponse>;
    selectAgendaContent(payload?: import('./types.admin').AdminSelectAgendaRequest): Promise<import('./types.admin').AdminSelectAgendaResponse>;
    selectContent(payload: import('./types.admin').AdminSelectContentRequest): Promise<import('./types.admin').AdminSelectContentResponse>;
    captureAppError(payload: import('./types.admin').AdminCaptureAppErrorRequest): Promise<void>;
    on: typeof on;
    toast: typeof toast;
};
export default _default;
