import { UiSelectAgendaRequest, UiSelectAgendaResponse, UiSelectCollectionPlayerRequest, UiSelectCollectionPlayerResponse, UiSelectContentRequest, UiSelectContentResponse, UiOpenRequest, UiToastRequest, UiPreselectSfdcMeetingIdRequest, UiPreselectSfdcMeetingIdResponse } from './types.ui';
/**
 * @hidden
 * @deprecated
 */
export declare function ui_select_content(payload?: UiSelectContentRequest): Promise<UiSelectContentResponse>;
/**
 * Allows the user to select (and preselect) content from the instance.
 *
 * Opens the content selector dialog to allow the user to select content and handle the outcome. This method allows you to
 * prompt the user to select content from the CatalogIQ instance and use that content in your application.
 *
 * @example
 * const api = useApi() // or useUi() if you know that you 're in UI context
 * api
 *   .selectContent({
 *     selections: [
 *       { fileId: "01HCZ623YYRFJQ0F7B69VWE510", type: "file" },
 *       {
 *         fileId: "01HD3XGZ5FN90QJGK7CH8TBZDF",
 *         type: "page",
 *         pageIndex: 2,
 *       },
 *     ],
 *   })
 *
 * @param payload optional payload to preselect specific content
 * @returns Promise with the user action and selected content
 */
export declare function selectContent(payload?: UiSelectContentRequest): Promise<UiSelectContentResponse>;
/**
 * Open a file in the CatalogIQ instance.
 */
export declare function open(payload: UiOpenRequest): Promise<void>;
/**
 * Show a toast message to the user.
 *
 * @example
 * useUi().toast({ type: 'info', message: 'Hello, world!' })
 */
export declare function toast(payload: UiToastRequest): Promise<void>;
/**
 * Preselect a meeting in the top meeting bar by Salesforce Meeting ID. From there, the user can easily start the meeting
 * with a single click.
 *
 * @example
 * const objectFetchedFromSalesforce = {
 *   // fetch dynamically from Salesforce or provide in another way
 *   EventId: '00U1r00000D1J1zEAF',
 * }
 * ui.preselectSfdcMeetingId({ eventId: objectFetchedFromSalesforce.EventId }).then((response) => {
 *   // e.g. display advanced meeting details inside your app
 *   console.log(response.event)
 * })
 */
export declare function preselectSfdcMeetingId(payload: UiPreselectSfdcMeetingIdRequest): Promise<UiPreselectSfdcMeetingIdResponse>;
/**
 * Opens the collection player selector modal to allow the user to select collection player content and handle the outcome.
 * ```
 * const api = useApi() // or useUi() if you know that you 're in UI context
 *
 * uiApi.selectCollectionContent({
 *  // optional payload
 *  initial_data: {
 *   name: 'test',
 *   groups: []
 *  }
 * })
 * ```
 */
export declare function selectCollectionContent(payload?: UiSelectCollectionPlayerRequest): Promise<UiSelectCollectionPlayerResponse>;
/**
 * Opens the agenda selector modal to allow the user to select agenda content and handle the outcome.
 * ```
 * const api = useApi() // or useUi() if you know that you 're in UI context
 *
 * uiApi.selectAgendaContent({
 *  // optional payload
 *  initial_agenda: {
 *   name: 'test',
 *   groups: []
 *  }
 * })
 * ```
 */
export declare function selectAgendaContent(payload?: UiSelectAgendaRequest): Promise<UiSelectAgendaResponse>;
