import { UiCompletePostcallRequest, UiSetPostcallStyleRequest } from './types.ui';
/**
 * Completes the postcall stage (with successful submission or not)
 *
 * @example
 * useUi().completePostcall({ was_successfully_submitted: true })
 */
export declare function completePostcall(payload: UiCompletePostcallRequest): Promise<void>;
/**
 * Cancels current meeting and the event remains unrealized (like it never happened).
 *
 * @example
 * useUi().cancelMeeting()
 */
export declare function cancelMeeting(): Promise<void>;
/**
 * Resumes the meeting and attempts to go at the last presented route / component.
 *
 * @example
 * useUi().resumeMeeting()
 */
export declare function resumeMeeting(): Promise<void>;
/**
 * Ends current meeting and shows postcall form.
 *
 * @example
 * useUi().stopMeeting()
 */
export declare function stopMeeting(): Promise<void>;
/**
 * Mark the postcall form as possible to submit by the user.
 *
 * @deprecated
 * @example
 * useUi().enablePostcallSubmit()
 */
export declare function enablePostcallSubmit(): Promise<void>;
/**
 * Mark the postcall form as **not** possible to submit by the user. Useful while processing the form data.
 *
 * @deprecated
 * @example
 * useUi().disablePostcallSubmit()
 */
export declare function disablePostcallSubmit(): Promise<void>;
/**
 * Change the height of the postcall form.
 *
 * @example
 * useUi().setPostcallStyle({ height: 100 })
 */
export declare function setPostcallStyle(payload: UiSetPostcallStyleRequest): Promise<void>;
