import { SelectedPage as ContentSelectorSelectedPage, SelectedFile as ContentSelectorSelectedFile, SelectorType } from '../../../../apps/content-selector/stores/app';
import { Selection } from '../../../../types/selections';
import { CanvasSelection } from '../../../../apps/canvas-selector/appTypes';
import { ComponentNode, EmbeddableProps } from '../../../../apps/canvas-builder/types/canvas';
import { SfEvent } from '../../../../types/sfdc';
import { Mutable } from '../../../../types/ts';
import { CanvasRetrieve, File, User, Canvas, CanvasSection, FileContentTypeEnum } from '../../../../../types/openapi';
import { OpenRequestPayload } from '../../../payload.types';
import { Range } from '../../../../util/tsHelpers';
import { Agenda, AgendaSelectorProps } from '../../../../apps/agenda-selector/types/agenda.type';
import { CollectionSelectorProps } from '../../../../apps/collection-selector/types/collection-selector.type';
import { CollectionPlayer } from '../../../../apps/collection-player/types/collection-player.type';
import { EmbedLocation } from '../../../../types/app';
export declare const UI_MESSAGE: "UI_MESSAGE";
export declare const UI_API_METHOD_TYPES: {
    readonly UI_BROADCAST: "ui_broadcast";
    readonly UI_SELECT_CONTENT: "ui_select_content";
    readonly UI_SELECT_CANVASES: "ui_select_canvases";
    readonly UI_OPEN: "ui_open";
    readonly UI_EMBEDDABLE_READY: "ui_embeddable_ready";
    readonly UI_TOAST: "ui_toast";
    readonly UI_CAPTURE_APP_ERROR: "ui_capture_app_error";
    readonly UI_UPDATE_CANVAS: "ui_update_canvas";
    readonly UI_OPEN_CANVAS_OVERLAY: "ui_open_canvas_overlay";
    readonly UI_SELECT_COLLECTION_PLAYER_CONTENT: "ui_select_collection_player_content";
    readonly UI_SELECT_AGENDA_CONTENT: "ui_select_agenda_content";
    readonly UI_UPDATE_LOCATION: "ui_update_location";
    readonly UI_PRESELECT_SFDC_MEETING_ID: "ui_preselect_sfdc_meeting_id";
    readonly UI_SET_POSTCALL_STYLE: "ui_set_postcall_style";
    readonly UI_ENABLE_POSTCALL_SUBMIT: "ui_enable_postcall_submit";
    readonly UI_DISABLE_POSTCALL_SUBMIT: "ui_disable_postcall_submit";
    readonly UI_COMPLETE_POSTCALL: "ui_complete_postcall";
    readonly UI_STOP_MEETING: "ui_stop_meeting";
    readonly UI_CANCEL_MEETING: "ui_cancel_meeting";
    readonly UI_RESUME_MEETING: "ui_resume_meeting";
    readonly UI_PROMPT_PIA: "ui_prompt_pia";
    readonly UI_CANVAS_NAVIGATE_NEXT_PAGE: "ui_canvas_navigate_next_page";
    readonly UI_CANVAS_NAVIGATE_PREVIOUS_PAGE: "ui_canvas_navigate_previous_page";
    readonly UI_CANVAS_NAVIGATE_PAGE: "ui_canvas_navigate_page";
    readonly UI_APP_LOADED: "ui_app_loaded";
    readonly UI_APP_RESIZE: "ui_app_resize";
    readonly UI_CLOSE_CANVAS_SECTION_EXECUTION: "ui_close_canvas_section_execution";
};
export declare const UI_MESSAGE_TYPES: {
    readonly UI_MEETING_CANCELED: "ui_meeting_canceled";
    readonly UI_CANVAS_UPDATED: "ui_canvas_updated";
    readonly UI_SECTION_LIST_UPDATED: "ui_section_list_updated";
    readonly UI_APP_SET_DATA: "ui_app_set_data";
    readonly UI_APP_UPDATE_DATA: "ui_app_update_data";
    readonly UI_PROMPT_PIA_RESPONSE_STREAMED: "ui_prompt_pia_response_streamed";
};
export declare const UI_NATIVE_MESSAGE_TYPES: readonly ["ui_app_set_data", "ui_app_update_data", "ui_canvas_updated"];
export type UiBroadcastRequest = Record<string, any>;
export type UiSelectContentRequest = {
    /** Array of selections */
    selections?: Selection[];
    content_type?: 'file' | 'slide' | 'content';
    allowed_selector_types?: SelectorType[];
    allowed_content_types?: FileContentTypeEnum[];
    allowed_asset_content_types?: FileContentTypeEnum[];
    max_selections?: number;
    min_selections?: Range<0, 999>;
    allowed_ids?: File['id'][];
    initial_metadata_filters?: Record<string, any>;
    /**
     * Array of file extensions to scope out list of the results (optional). Only files with these extensions will be shown.
     */
    allowed_original_extensions?: string[];
    /**
     * Disables files from selection which are not sharable (optional).
     */
    disable_no_sharable?: boolean;
};
export type UiSelectContentResponse = {
    /** User action result */
    user_action: 'cancelled' | 'selected';
    /** Selected content */
    content?: (ContentSelectorSelectedFile | ContentSelectorSelectedPage)[];
};
export type UiSelectCollectionPlayerRequest = {
    initial_data?: CollectionSelectorProps['initialData'];
    attach_to?: CollectionSelectorProps['attachTo'];
    open_settings?: CollectionSelectorProps['openSettings'];
    readonly_name?: CollectionSelectorProps['readonlyName'];
    close_on_settings?: CollectionSelectorProps['closeOnSettings'];
    translations?: CollectionSelectorProps['translations'];
    initial_metadata_filters?: CollectionSelectorProps['initialMetadataFilters'];
    hide_close?: CollectionSelectorProps['hideClose'];
};
export type UiSelectCollectionPlayerResponse = {
    /** User action result */
    user_action: 'cancelled' | 'selected' | 'settings';
    /** Selected content */
    content?: CollectionPlayer;
};
export type UiSelectAgendaRequest = {
    initial_agenda?: AgendaSelectorProps['initialAgenda'];
    attach_to?: AgendaSelectorProps['attachTo'];
};
export type UiSelectAgendaResponse = {
    /** User action result */
    user_action: 'cancelled' | 'selected';
    /** Selected content */
    content?: Agenda;
};
export type UiSelectCanvasesRequest = {
    /** Array of selections */
    selections?: CanvasSelection[];
    allowed_types?: ('canvas' | 'canvas-template' | 'section' | 'section-template')[];
    allowed_ids?: Canvas['id'][];
    initial_metadata_filters?: Record<string, any>;
};
export type UiSelectCanvasesResponse = {
    /** User action result */
    user_action: 'cancelled' | 'selected';
    /** Selected canvases */
    canvases?: Canvas[];
};
export type UiPromptPiaRequest = {
    /** Unique identifier of this prompt (needed for streaming event) */
    id: string;
    /** Prompt to send to PIA */
    prompt: string;
};
export type UiPromptPiaResponse = {
    /** Unique identifier of this prompt (needed for streaming event) */
    id: string;
    /** PIA response */
    response: string;
};
/**
 * Error object to send to Pitcher sentry instance
 */
export type UiCaptureAppErrorRequest = Record<string, any>;
export type UiUpdateCanvasRequest = Mutable<CanvasRetrieve> & {
    /** Comma-separated list of field keys to return from the server */
    fields?: string;
};
export type UiOpenRequest = OpenRequestPayload & {
    /** Name of the app to open */
    app_name?: string;
    /** Context to pass to the app */
    app_context?: Record<string, any>;
    /** Embed location of the app */
    app_embed_location?: EmbedLocation;
};
export type UiCompletePostcallRequest = {
    /** Indicates if the postcall was successfully submitted */
    was_successfully_submitted?: boolean;
};
export type UiSetPostcallStyleRequest = Record<string, any>;
export type UiAppResizeRequest = {
    /** Requested height as the number of pixels */
    height: number;
};
export type UiCanvasNavigatePageRequest = {
    /** The id of the component we want to navigate to */
    page: ComponentNode['id'];
};
export interface UiToastRequest {
    /**
     * Type of the toast, influences the default icon
     * @defaultValue **REQUIRED**
     */
    type: 'info' | 'error' | 'warning' | 'success' | 'loading';
    /**
     * Text to show inside the toast
     * @defaultValue **REQUIRED**
     */
    message: string;
    /**
     * Optional, value in milliseconds
     * @defaultValue 3500
     */
    duration?: number;
    /**
     * Visibility of the close button, default is true
     * @defaultValue true
     */
    closable?: boolean;
    /**
     * Toast won't be hidden as long as it is hovered
     * @defaultValue true
     */
    keepAliveOnHover?: boolean;
    /**
     * Set to `false` to hide the icon
     * @defaultValue true
     */
    showIcon?: boolean;
}
export interface UiPreselectSfdcMeetingIdRequest {
    /** Salesforce Meeting ID */
    eventId: string;
}
export interface UiPreselectSfdcMeetingIdResponse {
    /** Salesforce Event */
    event: SfEvent | null;
}
export type UiMessagePayloads = {
    [UI_MESSAGE_TYPES.UI_MEETING_CANCELED]: UiMeetingCanceledPayload;
    [UI_MESSAGE_TYPES.UI_APP_SET_DATA]: UiAppSetDataPayload;
    [UI_MESSAGE_TYPES.UI_APP_UPDATE_DATA]: UiAppUpdateDataPayload;
    [UI_MESSAGE_TYPES.UI_CANVAS_UPDATED]: UiCanvasUpdatedPayload;
    [UI_MESSAGE_TYPES.UI_SECTION_LIST_UPDATED]: UiSectionListUpdatedPayload;
    [UI_MESSAGE_TYPES.UI_PROMPT_PIA_RESPONSE_STREAMED]: UiPromptPiaResponseStreamedPayload;
};
export type UiMessageEnvelope<T extends (typeof UI_MESSAGE_TYPES)[keyof typeof UI_MESSAGE_TYPES] = (typeof UI_MESSAGE_TYPES)[keyof typeof UI_MESSAGE_TYPES]> = {
    /** Message type */
    type: T;
    /** Message body */
    body: UiMessagePayloads[T];
};
export type UiMeetingCanceledPayload = {
    /** Account ID */
    accountId?: string;
    /** Event ID */
    eventId?: string;
};
export type UiAppSetDataPayload = {
    /** Client name */
    client: string | null;
    /** Platform name */
    platform: string | undefined;
    /** User information */
    user: User | null;
    /** Edit mode status */
    is_edit_mode: boolean;
    /** Call status */
    in_call: boolean;
    /** Canvas data */
    canvas: CanvasRetrieve;
    /** Section used in canvas */
    used_in_section: CanvasSection | null;
    /** Component ID */
    component_id: string;
    /** Embeddable settings */
    settings: EmbeddableProps['settings'] | null;
    /** Width of the canvas */
    width: string | undefined;
    /** Height of the canvas */
    height: string | undefined;
    /** Display mode */
    display_mode: string | undefined;
    /** Section index in section list */
    section_index: number | null;
    /** Section list ID */
    section_list_id: string | null;
};
export type UiAppUpdateDataPayload = {
    /** Call status */
    in_call: boolean;
    /** Edit mode status */
    is_edit_mode: boolean;
};
export type UiCanvasUpdatedPayload = {
    /** Canvas data */
    canvas: CanvasRetrieve;
};
export type UiSectionListUpdatedPayload = {
    /** List of section IDs */
    section_list_ids: string[];
    /** Section list component ID */
    section_list_component_id: string;
    /** Canvas data */
    canvas: CanvasRetrieve | null;
};
export type UiPromptPiaResponseStreamedPayload = {
    /** Unique identifier of this prompt */
    id: string;
    /** PIA response so far */
    partial_response: string;
    /** Current chunk of the response */
    chunk: string;
};
