import { ApiOptions } from './interfaces';
import { createHighLevelApi } from './api/HighLevelApi';
export * from './interfaces';
export * from './payload.types';
export * from './api/modules/ui/types.ui';
export * from './api/modules/admin/types.admin';
export * from './api/modules/dsr/types.dsr';
export declare let highLevelApi: ReturnType<typeof createHighLevelApi>;
/**
 * Check out the returned object documentation for the list of available methods.
 */
export declare function usePitcherApi(options?: ApiOptions): ReturnType<typeof createHighLevelApi>;
/**
 * API methods available in the CatalogIQ default UI.
 *
 * You can store the API object in a variable and call the methods directly.
 *
 * Most methods have a `snake_case` and `camelCase` version of their name available.
 *
 * ```ts
 * const uiApi = useUi()
 * ```
 *
 * @returns UI API object with methods described below.
 */
export declare function useUi(): {
    promptPia(payload: import('./api/modules/ui/types.ui').UiPromptPiaRequest): Promise<import('./api/modules/ui/types.ui').UiPromptPiaResponse>;
    completePostcall(payload: import('./api/modules/ui/types.ui').UiCompletePostcallRequest): Promise<void>;
    cancelMeeting(): Promise<void>;
    resumeMeeting(): Promise<void>;
    stopMeeting(): Promise<void>;
    enablePostcallSubmit(): Promise<void>;
    disablePostcallSubmit(): Promise<void>;
    setPostcallStyle(payload: import('./api/modules/ui/types.ui').UiSetPostcallStyleRequest): Promise<void>;
    updateCanvas(payload: import('./api/modules/ui/types.ui').UiUpdateCanvasRequest): Promise<import('../main.lib').CanvasRetrieve>;
    appLoaded(): Promise<void>;
    appResize(payload: import('./api/modules/ui/types.ui').UiAppResizeRequest): Promise<void>;
    closeCanvasSectionExecution(): Promise<void>;
    canvasNavigateNextPage(): Promise<void>;
    canvasNavigatePreviousPage(): Promise<void>;
    canvasNavigatePage(payload: import('./api/modules/ui/types.ui').UiCanvasNavigatePageRequest): Promise<void>;
    openCanvasOverlay(payload: {
        id: import('../main.lib').CanvasRetrieve["id"];
        edit_mode?: boolean;
        fullscreen?: boolean;
        component_id?: string;
        section_id?: string;
        position?: {
            left?: number | string;
            right?: number | string;
            top?: number | string;
            bottom?: number | string;
        };
    }): Promise<void>;
    selectCanvases(payload?: import('./api/modules/ui/types.ui').UiSelectCanvasesRequest): Promise<import('./api/modules/ui/types.ui').UiSelectCanvasesResponse>;
    captureAppError(payload: import('./api/modules/ui/types.ui').UiCaptureAppErrorRequest): Promise<void>;
    updateLocation(payload: import('./interfaces').UpdateLocationPitcherEvent): Promise<any>;
    embeddableReady(): Promise<void>;
    ui_select_content(payload?: import('./api/modules/ui/types.ui').UiSelectContentRequest): Promise<import('./api/modules/ui/types.ui').UiSelectContentResponse>;
    selectContent(payload?: import('./api/modules/ui/types.ui').UiSelectContentRequest): Promise<import('./api/modules/ui/types.ui').UiSelectContentResponse>;
    open(payload: import('./api/modules/ui/types.ui').UiOpenRequest): Promise<void>;
    toast(payload: import('./api/modules/ui/types.ui').UiToastRequest): Promise<void>;
    preselectSfdcMeetingId(payload: import('./api/modules/ui/types.ui').UiPreselectSfdcMeetingIdRequest): Promise<import('./api/modules/ui/types.ui').UiPreselectSfdcMeetingIdResponse>;
    selectCollectionContent(payload?: import('./api/modules/ui/types.ui').UiSelectCollectionPlayerRequest): Promise<import('./api/modules/ui/types.ui').UiSelectCollectionPlayerResponse>;
    selectAgendaContent(payload?: import('./api/modules/ui/types.ui').UiSelectAgendaRequest): Promise<import('./api/modules/ui/types.ui').UiSelectAgendaResponse>;
    on: <T extends keyof import('./api/modules/ui/types.ui').UiMessagePayloads>(type: T, handler: (data: import('./api/modules/ui/types.ui').UiMessagePayloads[T]) => Promise<void>) => Promise<() => void>;
    onMeetingCanceled: (handler: (data: import('./api/modules/ui/types.ui').UiMeetingCanceledPayload) => Promise<void>) => Promise<() => void>;
    onCanvasUpdated: (handler: (data: import('./api/modules/ui/types.ui').UiCanvasUpdatedPayload) => Promise<void>) => Promise<() => void>;
    onSectionListUpdated: (handler: (data: import('./api/modules/ui/types.ui').UiSectionListUpdatedPayload) => Promise<void>) => Promise<() => void>;
    onAppSetData: (handler: (data: import('./api/modules/ui/types.ui').UiAppSetDataPayload) => Promise<void>) => Promise<() => void>;
    onAppUpdateData: (handler: (data: import('./api/modules/ui/types.ui').UiAppUpdateDataPayload) => Promise<void>) => Promise<() => void>;
    uiBroadcast: (payload: import('./api/modules/ui/types.ui').UiBroadcastRequest) => Promise<void>;
};
/**
 * API methods available in the CatalogIQ Admin.
 *
 * You can store the API object in a variable and call the methods directly.
 *
 * Most methods have a `snake_case` and `camelCase` version of their name available.
 *
 * ```ts
 * import { useAdmin } from '@pitcher/js-api'
 *
 * const adminApi = useAdmin()
 * ```
 */
export declare function useAdmin(): {
    getUsers(payload?: import('../main.lib').GetUsersParams): Promise<import('../main.lib').PaginatedData<import('../main.lib').User>>;
    getAppConfig(payload: {
        app_name: string;
    }): Promise<Record<string, any>>;
    getFile(payload: {
        id: import('../main.lib').File["id"];
    }): Promise<import('../main.lib').File>;
    getFiles(payload: Record<string, any>): Promise<import('../main.lib').PaginatedFileList>;
    open(payload: {
        id: import('../main.lib').File["id"];
    }): Promise<void>;
    close(): Promise<void>;
    getInstanceMetadataTemplates(payload?: import('./payload.types').GetInstanceMetadataTemplatesPayload): Promise<import('../main.lib').PaginatedMetadataTemplateList>;
    createCanvas(payload: import('../main.lib').CanvasCreateRequest): Promise<import('../main.lib').CanvasRetrieve>;
    getCanvases(payload: import('../main.lib').GetCanvasesParams & {
        filters?: Record<string, any>;
        fields?: string;
    }): Promise<import('../main.lib').PaginatedData<import('../main.lib').CanvasRetrieve>>;
    getCanvas(payload: {
        id: import('../main.lib').CanvasRetrieve["id"];
        fields?: string;
    }): Promise<import('../main.lib').CanvasRetrieve>;
    updateCanvas(payload: import('../main.lib').PatchedCanvasUpdateRequest & {
        id: import('../main.lib').CanvasRetrieve["id"];
        instance_id?: import('../main.lib').Instance["id"];
        fields?: string;
    }): Promise<import('../main.lib').CanvasRetrieve>;
    openCanvasOverlay(payload: {
        id: import('../main.lib').CanvasRetrieve["id"];
        edit_mode?: boolean;
        fullscreen?: boolean;
        component_id?: string;
        section_id?: string;
        position?: {
            left?: number | string;
            right?: number | string;
            top?: number | string;
            bottom?: number | string;
        };
    }): Promise<void>;
    selectCanvases(payload?: import('./api/modules/admin/types.admin').AdminSelectCanvasesRequest): Promise<import('./api/modules/admin/types.admin').AdminSelectCanvasesResponse>;
    getEnv(): Promise<import('./api/modules/admin/types.admin').AdminEnv>;
    selectCollectionContent(payload?: import('./api/modules/admin/types.admin').AdminSelectCollectionPlayerRequest): Promise<import('./api/modules/admin/types.admin').AdminSelectCollectionPlayerResponse>;
    selectAgendaContent(payload?: import('./api/modules/admin/types.admin').AdminSelectAgendaRequest): Promise<import('./api/modules/admin/types.admin').AdminSelectAgendaResponse>;
    selectContent(payload: import('./api/modules/admin/types.admin').AdminSelectContentRequest): Promise<import('./api/modules/admin/types.admin').AdminSelectContentResponse>;
    captureAppError(payload: import('./api/modules/admin/types.admin').AdminCaptureAppErrorRequest): Promise<void>;
    on: (type: typeof import('./api/modules/admin/types.admin').ADMIN_MESSAGE_TYPES[keyof typeof import('./api/modules/admin/types.admin').ADMIN_MESSAGE_TYPES], handler: (data: import('./api/modules/admin/types.admin').AdminMessagePayloads[typeof type]) => Promise<void>) => Promise<() => void>;
    toast: (payload: import('./api/modules/admin/types.admin').AdminToastRequest) => Promise<void>;
};
/**
 * API methods available in the CatalogIQ default UI.
 *
 * You can store the API object in a variable and call the methods directly.
 *
 * Most methods have a `snake_case` and `camelCase` version of their name available.
 *
 * ```ts
 * import { useDsr } from '@pitcher/js-api'
 *
 * const dsrApi = useDsr()
 * ```
 */
export declare function useDsr(): {
    close(): Promise<void>;
    getFile(payload: {
        id: import('../main.lib').File["id"];
    }): Promise<import('../main.lib').File>;
    embeddableReady(): Promise<void>;
    getEnv(): Promise<import('./api/modules/dsr/types.dsr').DsrEnv>;
    on: (type: typeof import('./api/modules/dsr/types.dsr').DSR_MESSAGE_TYPES[keyof typeof import('./api/modules/dsr/types.dsr').DSR_MESSAGE_TYPES], handler: (data: import('./api/modules/dsr/types.dsr').DsrMessagePayloads[typeof type]) => Promise<void>) => Promise<() => void>;
};
export type JsApiLocation = 'ui' | 'admin' | 'dsr' | 'impact';
export declare function getAvailableApis(): JsApiLocation[];
/**
 * This method returns an object containing the API methods that are available to you in a given environment, whether that be the Canvas, UI, Admin or DSR.
 *
 * - CatalogIQ UI - the method will return an object containing methods available in both `usePitcherApi` and `useUi`
 * - CatalogIQ DSR - the method will return the same result as `useDsr`
 * - CatalogIQ Admin - the method will return the same result as `useAdmin`
 *
 * ```ts
 * import { useApi } from '@pitcher/js-api'
 *
 * const api = useApi()
 * ```
 */
export declare function useApi(options?: ApiOptions): {
    on: (type: string, callback: (payload: import('./interfaces').PitcherEvent) => void) => void;
    off: (type: string, callback: (payload: import('./interfaces').PitcherEvent) => void) => void;
    enterFullscreen: () => Promise<any>;
    exitFullscreen: () => Promise<any>;
    isFullscreen: () => Promise<any>;
    logout: () => Promise<any>;
    quitInstance: () => Promise<any>;
    getRequestTypes: () => Promise<any>;
    broadcast: (event: import('./interfaces').PitcherEvent) => Promise<any>;
    subscribe: () => Promise<any>;
    unsubscribe: () => Promise<any>;
    open(payload?: import('./payload.types').OpenRequestPayload): Promise<string>;
    openExternalUrl(payload: import('./payload.types').OpenExternalUrlRequestPayload): Promise<void>;
    getEnv(): Promise<import('./interfaces').PitcherEnv>;
    updateMyUser(payload: {
        language?: import('../main.lib').LanguageEnum | undefined;
    }): Promise<import('../main.lib').User>;
    isOffline(): Promise<boolean>;
    getLanguages(): Promise<import('./api/modules').Language[]>;
    getEvents(payload: Partial<import('../main.lib').EventRequest>): Promise<import('../main.lib').PaginatedData<import('../main.lib').Event>>;
    createEvent(payload: import('../main.lib').EventRequest): Promise<import('../main.lib').Event>;
    updateEvent(payload: import('../main.lib').PatchedEventRequest): Promise<import('../main.lib').Event>;
    deleteEvent(payload: Partial<import('../main.lib').Event>): Promise<void>;
    getCanvases(payload: import('../main.lib').GetCanvasesParams & {
        filters?: Record<string, any>;
        fields?: string;
    }): Promise<import('../main.lib').PaginatedData<import('../main.lib').CanvasRetrieve>>;
    createCanvas(payload: Omit<import('../main.lib').CanvasCreateRequest, "instance_id">): Promise<import('../main.lib').CanvasRetrieve>;
    deleteCanvas(payload: {
        id: import('../main.lib').CanvasRetrieve["id"];
    }): Promise<import('../main.lib').CanvasRetrieve>;
    updateCanvas(payload: import('../main.lib').PatchedCanvasUpdateRequest & {
        id: import('../main.lib').CanvasRetrieve["id"];
        instance_id?: import('../main.lib').Instance["id"];
        fields?: string;
    }): Promise<import('../main.lib').CanvasRetrieve>;
    updateCanvasIndicators(payload: {
        indicators: Record<string, import('../main.lib').CanvasIndicator>;
        id: import('../main.lib').CanvasRetrieve["id"];
        instance_id?: import('../main.lib').Instance["id"];
    }): Promise<import('../main.lib').CanvasRetrieve>;
    getCanvas(payload: {
        id: import('../main.lib').CanvasRetrieve["id"];
        fields?: string;
    }): Promise<import('../main.lib').CanvasRetrieve>;
    shareCanvas(payload: {
        id: import('../main.lib').CanvasRetrieve["id"];
    }): Promise<import('../main.lib').SharedLink>;
    getCanvasRecommendedFiles(payload: {
        canvas_id: import('../main.lib').CanvasRetrieve["id"];
        match?: ("tags" | "metadata")[];
    }): Promise<import('../main.lib').CanvasRecommendedFiles>;
    getCanvasTheme(payload: {
        canvas_id: import('../main.lib').CanvasRetrieve["id"];
    }): Promise<import('../main.lib').CanvasThemeRetrieve>;
    unassignCanvasTheme(payload: {
        canvas_id: import('../main.lib').CanvasRetrieve["id"];
    }): Promise<void>;
    getFiles(payload: import('./payload.types').ListFilesPayload & {
        filters?: Record<string, any>;
        fields?: string;
    }): Promise<import('../main.lib').PaginatedFileList>;
    getRecentFiles(payload?: import('./payload.types').GetRecentFilesPayload): Promise<import('../main.lib').File[]>;
    downloadFile(payload: {
        file_id: import('../main.lib').File["id"];
    }): Promise<null>;
    getAppConfig(payload: {
        app_name: string;
    }): Promise<Record<string, any>>;
    getFile(payload: {
        id?: import('../main.lib').FileRetrieve["id"];
        file_id?: import('../main.lib').FileRetrieve["id"];
    }): Promise<import('../main.lib').FileRetrieve>;
    getFileRevisionData(payload: {
        file_id: import('../main.lib').FileRetrieve["id"];
        revision_id: import('../main.lib').FileRevision["id"];
    }): Promise<import('../main.lib').FileRetrieve>;
    updateFile(payload: import('../main.lib').FileUpdateRequest & {
        id: import('../main.lib').File["id"];
    }): Promise<import('../main.lib').FileRetrieve>;
    deleteFile(payload: {
        file_id: import('../main.lib').File["id"];
    }): Promise<import('../main.lib').File["id"]>;
    createFile(payload: Omit<import('../main.lib').AllFileCreateRequest, "instance_id">): Promise<import('../main.lib').FileRetrieve>;
    selectDeviceFile(): Promise<import('../main.lib').DeviceFile>;
    getFileRevisions(payload: {
        id?: import('../main.lib').FileRetrieve["id"];
        file_id?: import('../main.lib').FileRetrieve["id"];
    }): Promise<import('../main.lib').FileRevision[]>;
    search(payload: {
        query: string;
        includeExpired?: boolean;
    }): Promise<any>;
    getUsers(payload?: import('../main.lib').GetUsersParams): Promise<import('../main.lib').PaginatedData<import('../main.lib').User>>;
    refreshServiceToken(payload?: import('../main.lib').RefreshServiceTokenRequest): Promise<import('../main.lib').RefreshServiceTokenResponse>;
    refreshAccessToken(): any;
    fetchDocumentInfo(payload: {
        fileId: import('../main.lib').File["id"];
    }): Promise<{
        pageCount: number;
        [key: string]: unknown;
    }>;
    renderPageAsImage(payload: {
        fileId: import('../main.lib').File["id"];
        documentId?: import('../main.lib').File["id"];
        pageIndex: number;
        params: {
            width: number;
        } | {
            height: number;
        };
    }): Promise<ArrayBuffer>;
    toast(payload: {
        type: string;
        message: string;
    }): Promise<void>;
    query(payload: import('./payload.types').QueryPayload): Promise<any>;
    crmQuery(payload: import('./payload.types').CRMQueryPayload): Promise<any>;
    getFolders(payload: import('./payload.types').FolderListRequest): Promise<import('../main.lib').PaginatedFolderList>;
    getFolder(payload?: {
        id: import('../main.lib').FolderRetrieve["id"];
    }): Promise<import('../main.lib').FolderRetrieve>;
    createFolder(payload: Omit<import('../main.lib').FolderCreateRequest, "instance_id">): Promise<import('../main.lib').FolderRetrieve>;
    updateFolder(payload: import('../main.lib').FolderUpdateRequest & {
        id: import('../main.lib').Folder["id"];
    }): Promise<import('../main.lib').FolderRetrieve>;
    deleteFolder(payload: {
        folder_id: import('../main.lib').FolderRetrieve["id"];
    }): Promise<void>;
    moveFolderItems(payload: {
        target_folder_id: import('../main.lib').Folder["id"];
        items: {
            id: import('../main.lib').File["id"] | import('../main.lib').Folder["id"];
            type: "folder" | "file";
        }[];
    }): Promise<import('../main.lib').FolderRetrieve>;
    getCoreFolders(payload: {
        instance_id: string;
        entity: import('../main.lib').CoreFolderEntityType;
        parent_id?: string | null;
    }): Promise<import('../main.lib').CoreFolderContentsRetrieve>;
    patchCoreFolder(id: string, payload: Partial<import('../main.lib').CoreFolderRetrieve>): Promise<import('../main.lib').CoreFolderContentsRetrieve>;
    getFavorites(payload?: import('../main.lib').GetFavoritesParams): Promise<import('../main.lib').PaginatedFavoriteList>;
    createFavorite(payload: import('../main.lib').FavoriteCreateRequest): Promise<import('../main.lib').Favorite>;
    deleteFavorite(payload: {
        favorite_id: import('../main.lib').Favorite["id"];
    }): Promise<void>;
    notify(payload: import('./payload.types').NotificationPayload): Promise<void>;
    track(payload: {
        event_name: string;
        payload: any;
    }): Promise<any>;
    getInstanceMetadataTemplates(payload?: import('./payload.types').GetInstanceMetadataTemplatesPayload): Promise<import('../main.lib').PaginatedMetadataTemplateList>;
    triggerNonFilesSync(): Promise<void>;
    submitUserFeedback(payload: import('./payload.types').SubmitUserFeedbackPayload): Promise<any>;
    close(): Promise<any>;
    openWebViewAlwaysOnTop(payload: import('./payload.types').OpenWebViewAlwaysOnTop): Promise<void>;
    share(payload: import('./payload.types').SharePayload): Promise<import('./payload.types').ShareResponse>;
    getThemes(payload: Partial<import('../main.lib').CanvasThemeRetrieve>): Promise<import('../main.lib').CanvasThemeRetrieve[]>;
    assignCanvasTheme(payload: {
        canvas_id: import('../main.lib').CanvasRetrieve["id"];
        theme_id: import('../main.lib').CanvasThemeRetrieve["id"];
    }): Promise<{
        canvas_id: import('../main.lib').CanvasRetrieve["id"];
        theme_id: import('../main.lib').CanvasThemeRetrieve["id"];
    }>;
    API: import('./api/LowLevelApi').LowLevelApi;
} | {
    getUsers(payload?: import('../main.lib').GetUsersParams): Promise<import('../main.lib').PaginatedData<import('../main.lib').User>>;
    getAppConfig(payload: {
        app_name: string;
    }): Promise<Record<string, any>>;
    getFile(payload: {
        id: import('../main.lib').File["id"];
    }): Promise<import('../main.lib').File>;
    getFiles(payload: Record<string, any>): Promise<import('../main.lib').PaginatedFileList>;
    open(payload: {
        id: import('../main.lib').File["id"];
    }): Promise<void>;
    close(): Promise<void>;
    getInstanceMetadataTemplates(payload?: import('./payload.types').GetInstanceMetadataTemplatesPayload): Promise<import('../main.lib').PaginatedMetadataTemplateList>;
    createCanvas(payload: import('../main.lib').CanvasCreateRequest): Promise<import('../main.lib').CanvasRetrieve>;
    getCanvases(payload: import('../main.lib').GetCanvasesParams & {
        filters?: Record<string, any>;
        fields?: string;
    }): Promise<import('../main.lib').PaginatedData<import('../main.lib').CanvasRetrieve>>;
    getCanvas(payload: {
        id: import('../main.lib').CanvasRetrieve["id"];
        fields?: string;
    }): Promise<import('../main.lib').CanvasRetrieve>;
    updateCanvas(payload: import('../main.lib').PatchedCanvasUpdateRequest & {
        id: import('../main.lib').CanvasRetrieve["id"];
        instance_id?: import('../main.lib').Instance["id"];
        fields?: string;
    }): Promise<import('../main.lib').CanvasRetrieve>;
    openCanvasOverlay(payload: {
        id: import('../main.lib').CanvasRetrieve["id"];
        edit_mode?: boolean;
        fullscreen?: boolean;
        component_id?: string;
        section_id?: string;
        position?: {
            left?: number | string;
            right?: number | string;
            top?: number | string;
            bottom?: number | string;
        };
    }): Promise<void>;
    selectCanvases(payload?: import('./api/modules/admin/types.admin').AdminSelectCanvasesRequest): Promise<import('./api/modules/admin/types.admin').AdminSelectCanvasesResponse>;
    getEnv(): Promise<import('./api/modules/admin/types.admin').AdminEnv>;
    selectCollectionContent(payload?: import('./api/modules/admin/types.admin').AdminSelectCollectionPlayerRequest): Promise<import('./api/modules/admin/types.admin').AdminSelectCollectionPlayerResponse>;
    selectAgendaContent(payload?: import('./api/modules/admin/types.admin').AdminSelectAgendaRequest): Promise<import('./api/modules/admin/types.admin').AdminSelectAgendaResponse>;
    selectContent(payload: import('./api/modules/admin/types.admin').AdminSelectContentRequest): Promise<import('./api/modules/admin/types.admin').AdminSelectContentResponse>;
    captureAppError(payload: import('./api/modules/admin/types.admin').AdminCaptureAppErrorRequest): Promise<void>;
    on: (type: typeof import('./api/modules/admin/types.admin').ADMIN_MESSAGE_TYPES[keyof typeof import('./api/modules/admin/types.admin').ADMIN_MESSAGE_TYPES], handler: (data: import('./api/modules/admin/types.admin').AdminMessagePayloads[typeof type]) => Promise<void>) => Promise<() => void>;
    toast: (payload: import('./api/modules/admin/types.admin').AdminToastRequest) => Promise<void>;
} | {
    close(): Promise<void>;
    getFile(payload: {
        id: import('../main.lib').File["id"];
    }): Promise<import('../main.lib').File>;
    embeddableReady(): Promise<void>;
    getEnv(): Promise<import('./api/modules/dsr/types.dsr').DsrEnv>;
    on: (type: typeof import('./api/modules/dsr/types.dsr').DSR_MESSAGE_TYPES[keyof typeof import('./api/modules/dsr/types.dsr').DSR_MESSAGE_TYPES], handler: (data: import('./api/modules/dsr/types.dsr').DsrMessagePayloads[typeof type]) => Promise<void>) => Promise<() => void>;
} | {
    ui: {
        promptPia(payload: import('./api/modules/ui/types.ui').UiPromptPiaRequest): Promise<import('./api/modules/ui/types.ui').UiPromptPiaResponse>;
        completePostcall(payload: import('./api/modules/ui/types.ui').UiCompletePostcallRequest): Promise<void>;
        cancelMeeting(): Promise<void>;
        resumeMeeting(): Promise<void>;
        stopMeeting(): Promise<void>;
        enablePostcallSubmit(): Promise<void>;
        disablePostcallSubmit(): Promise<void>;
        setPostcallStyle(payload: import('./api/modules/ui/types.ui').UiSetPostcallStyleRequest): Promise<void>;
        updateCanvas(payload: import('./api/modules/ui/types.ui').UiUpdateCanvasRequest): Promise<import('../main.lib').CanvasRetrieve>;
        appLoaded(): Promise<void>;
        appResize(payload: import('./api/modules/ui/types.ui').UiAppResizeRequest): Promise<void>;
        closeCanvasSectionExecution(): Promise<void>;
        canvasNavigateNextPage(): Promise<void>;
        canvasNavigatePreviousPage(): Promise<void>;
        canvasNavigatePage(payload: import('./api/modules/ui/types.ui').UiCanvasNavigatePageRequest): Promise<void>;
        openCanvasOverlay(payload: {
            id: import('../main.lib').CanvasRetrieve["id"];
            edit_mode?: boolean;
            fullscreen?: boolean;
            component_id?: string;
            section_id?: string;
            position?: {
                left?: number | string;
                right?: number | string;
                top?: number | string;
                bottom?: number | string;
            };
        }): Promise<void>;
        selectCanvases(payload?: import('./api/modules/ui/types.ui').UiSelectCanvasesRequest): Promise<import('./api/modules/ui/types.ui').UiSelectCanvasesResponse>;
        captureAppError(payload: import('./api/modules/ui/types.ui').UiCaptureAppErrorRequest): Promise<void>;
        updateLocation(payload: import('./interfaces').UpdateLocationPitcherEvent): Promise<any>;
        embeddableReady(): Promise<void>;
        ui_select_content(payload?: import('./api/modules/ui/types.ui').UiSelectContentRequest): Promise<import('./api/modules/ui/types.ui').UiSelectContentResponse>;
        selectContent(payload?: import('./api/modules/ui/types.ui').UiSelectContentRequest): Promise<import('./api/modules/ui/types.ui').UiSelectContentResponse>;
        open(payload: import('./api/modules/ui/types.ui').UiOpenRequest): Promise<void>;
        toast(payload: import('./api/modules/ui/types.ui').UiToastRequest): Promise<void>;
        preselectSfdcMeetingId(payload: import('./api/modules/ui/types.ui').UiPreselectSfdcMeetingIdRequest): Promise<import('./api/modules/ui/types.ui').UiPreselectSfdcMeetingIdResponse>;
        selectCollectionContent(payload?: import('./api/modules/ui/types.ui').UiSelectCollectionPlayerRequest): Promise<import('./api/modules/ui/types.ui').UiSelectCollectionPlayerResponse>;
        selectAgendaContent(payload?: import('./api/modules/ui/types.ui').UiSelectAgendaRequest): Promise<import('./api/modules/ui/types.ui').UiSelectAgendaResponse>;
        on: <T extends keyof import('./api/modules/ui/types.ui').UiMessagePayloads>(type: T, handler: (data: import('./api/modules/ui/types.ui').UiMessagePayloads[T]) => Promise<void>) => Promise<() => void>;
        onMeetingCanceled: (handler: (data: import('./api/modules/ui/types.ui').UiMeetingCanceledPayload) => Promise<void>) => Promise<() => void>;
        onCanvasUpdated: (handler: (data: import('./api/modules/ui/types.ui').UiCanvasUpdatedPayload) => Promise<void>) => Promise<() => void>;
        onSectionListUpdated: (handler: (data: import('./api/modules/ui/types.ui').UiSectionListUpdatedPayload) => Promise<void>) => Promise<() => void>;
        onAppSetData: (handler: (data: import('./api/modules/ui/types.ui').UiAppSetDataPayload) => Promise<void>) => Promise<() => void>;
        onAppUpdateData: (handler: (data: import('./api/modules/ui/types.ui').UiAppUpdateDataPayload) => Promise<void>) => Promise<() => void>;
        uiBroadcast: (payload: import('./api/modules/ui/types.ui').UiBroadcastRequest) => Promise<void>;
    };
    impact: {
        on: (type: string, callback: (payload: import('./interfaces').PitcherEvent) => void) => void;
        off: (type: string, callback: (payload: import('./interfaces').PitcherEvent) => void) => void;
        enterFullscreen: () => Promise<any>;
        exitFullscreen: () => Promise<any>;
        isFullscreen: () => Promise<any>;
        logout: () => Promise<any>;
        quitInstance: () => Promise<any>;
        getRequestTypes: () => Promise<any>;
        broadcast: (event: import('./interfaces').PitcherEvent) => Promise<any>;
        subscribe: () => Promise<any>;
        unsubscribe: () => Promise<any>;
        open(payload?: import('./payload.types').OpenRequestPayload): Promise<string>;
        openExternalUrl(payload: import('./payload.types').OpenExternalUrlRequestPayload): Promise<void>;
        getEnv(): Promise<import('./interfaces').PitcherEnv>;
        updateMyUser(payload: {
            language?: import('../main.lib').LanguageEnum | undefined;
        }): Promise<import('../main.lib').User>;
        isOffline(): Promise<boolean>;
        getLanguages(): Promise<import('./api/modules').Language[]>;
        getEvents(payload: Partial<import('../main.lib').EventRequest>): Promise<import('../main.lib').PaginatedData<import('../main.lib').Event>>;
        createEvent(payload: import('../main.lib').EventRequest): Promise<import('../main.lib').Event>;
        updateEvent(payload: import('../main.lib').PatchedEventRequest): Promise<import('../main.lib').Event>;
        deleteEvent(payload: Partial<import('../main.lib').Event>): Promise<void>;
        getCanvases(payload: import('../main.lib').GetCanvasesParams & {
            filters?: Record<string, any>;
            fields?: string;
        }): Promise<import('../main.lib').PaginatedData<import('../main.lib').CanvasRetrieve>>;
        createCanvas(payload: Omit<import('../main.lib').CanvasCreateRequest, "instance_id">): Promise<import('../main.lib').CanvasRetrieve>;
        deleteCanvas(payload: {
            id: import('../main.lib').CanvasRetrieve["id"];
        }): Promise<import('../main.lib').CanvasRetrieve>;
        updateCanvas(payload: import('../main.lib').PatchedCanvasUpdateRequest & {
            id: import('../main.lib').CanvasRetrieve["id"];
            instance_id?: import('../main.lib').Instance["id"];
            fields?: string;
        }): Promise<import('../main.lib').CanvasRetrieve>;
        updateCanvasIndicators(payload: {
            indicators: Record<string, import('../main.lib').CanvasIndicator>;
            id: import('../main.lib').CanvasRetrieve["id"];
            instance_id?: import('../main.lib').Instance["id"];
        }): Promise<import('../main.lib').CanvasRetrieve>;
        getCanvas(payload: {
            id: import('../main.lib').CanvasRetrieve["id"];
            fields?: string;
        }): Promise<import('../main.lib').CanvasRetrieve>;
        shareCanvas(payload: {
            id: import('../main.lib').CanvasRetrieve["id"];
        }): Promise<import('../main.lib').SharedLink>;
        getCanvasRecommendedFiles(payload: {
            canvas_id: import('../main.lib').CanvasRetrieve["id"];
            match?: ("tags" | "metadata")[];
        }): Promise<import('../main.lib').CanvasRecommendedFiles>;
        getCanvasTheme(payload: {
            canvas_id: import('../main.lib').CanvasRetrieve["id"];
        }): Promise<import('../main.lib').CanvasThemeRetrieve>;
        unassignCanvasTheme(payload: {
            canvas_id: import('../main.lib').CanvasRetrieve["id"];
        }): Promise<void>;
        getFiles(payload: import('./payload.types').ListFilesPayload & {
            filters?: Record<string, any>;
            fields?: string;
        }): Promise<import('../main.lib').PaginatedFileList>;
        getRecentFiles(payload?: import('./payload.types').GetRecentFilesPayload): Promise<import('../main.lib').File[]>;
        downloadFile(payload: {
            file_id: import('../main.lib').File["id"];
        }): Promise<null>;
        getAppConfig(payload: {
            app_name: string;
        }): Promise<Record<string, any>>;
        getFile(payload: {
            id?: import('../main.lib').FileRetrieve["id"];
            file_id?: import('../main.lib').FileRetrieve["id"];
        }): Promise<import('../main.lib').FileRetrieve>;
        getFileRevisionData(payload: {
            file_id: import('../main.lib').FileRetrieve["id"];
            revision_id: import('../main.lib').FileRevision["id"];
        }): Promise<import('../main.lib').FileRetrieve>;
        updateFile(payload: import('../main.lib').FileUpdateRequest & {
            id: import('../main.lib').File["id"];
        }): Promise<import('../main.lib').FileRetrieve>;
        deleteFile(payload: {
            file_id: import('../main.lib').File["id"];
        }): Promise<import('../main.lib').File["id"]>;
        createFile(payload: Omit<import('../main.lib').AllFileCreateRequest, "instance_id">): Promise<import('../main.lib').FileRetrieve>;
        selectDeviceFile(): Promise<import('../main.lib').DeviceFile>;
        getFileRevisions(payload: {
            id?: import('../main.lib').FileRetrieve["id"];
            file_id?: import('../main.lib').FileRetrieve["id"];
        }): Promise<import('../main.lib').FileRevision[]>;
        search(payload: {
            query: string;
            includeExpired?: boolean;
        }): Promise<any>;
        getUsers(payload?: import('../main.lib').GetUsersParams): Promise<import('../main.lib').PaginatedData<import('../main.lib').User>>;
        refreshServiceToken(payload?: import('../main.lib').RefreshServiceTokenRequest): Promise<import('../main.lib').RefreshServiceTokenResponse>;
        refreshAccessToken(): any;
        fetchDocumentInfo(payload: {
            fileId: import('../main.lib').File["id"];
        }): Promise<{
            pageCount: number;
            [key: string]: unknown;
        }>;
        renderPageAsImage(payload: {
            fileId: import('../main.lib').File["id"];
            documentId?: import('../main.lib').File["id"];
            pageIndex: number;
            params: {
                width: number;
            } | {
                height: number;
            };
        }): Promise<ArrayBuffer>;
        toast(payload: {
            type: string;
            message: string;
        }): Promise<void>;
        query(payload: import('./payload.types').QueryPayload): Promise<any>;
        crmQuery(payload: import('./payload.types').CRMQueryPayload): Promise<any>;
        getFolders(payload: import('./payload.types').FolderListRequest): Promise<import('../main.lib').PaginatedFolderList>;
        getFolder(payload?: {
            id: import('../main.lib').FolderRetrieve["id"];
        }): Promise<import('../main.lib').FolderRetrieve>;
        createFolder(payload: Omit<import('../main.lib').FolderCreateRequest, "instance_id">): Promise<import('../main.lib').FolderRetrieve>;
        updateFolder(payload: import('../main.lib').FolderUpdateRequest & {
            id: import('../main.lib').Folder["id"];
        }): Promise<import('../main.lib').FolderRetrieve>;
        deleteFolder(payload: {
            folder_id: import('../main.lib').FolderRetrieve["id"];
        }): Promise<void>;
        moveFolderItems(payload: {
            target_folder_id: import('../main.lib').Folder["id"];
            items: {
                id: import('../main.lib').File["id"] | import('../main.lib').Folder["id"];
                type: "folder" | "file";
            }[];
        }): Promise<import('../main.lib').FolderRetrieve>;
        getCoreFolders(payload: {
            instance_id: string;
            entity: import('../main.lib').CoreFolderEntityType;
            parent_id?: string | null;
        }): Promise<import('../main.lib').CoreFolderContentsRetrieve>;
        patchCoreFolder(id: string, payload: Partial<import('../main.lib').CoreFolderRetrieve>): Promise<import('../main.lib').CoreFolderContentsRetrieve>;
        getFavorites(payload?: import('../main.lib').GetFavoritesParams): Promise<import('../main.lib').PaginatedFavoriteList>;
        createFavorite(payload: import('../main.lib').FavoriteCreateRequest): Promise<import('../main.lib').Favorite>;
        deleteFavorite(payload: {
            favorite_id: import('../main.lib').Favorite["id"];
        }): Promise<void>;
        notify(payload: import('./payload.types').NotificationPayload): Promise<void>;
        track(payload: {
            event_name: string;
            payload: any;
        }): Promise<any>;
        getInstanceMetadataTemplates(payload?: import('./payload.types').GetInstanceMetadataTemplatesPayload): Promise<import('../main.lib').PaginatedMetadataTemplateList>;
        triggerNonFilesSync(): Promise<void>;
        submitUserFeedback(payload: import('./payload.types').SubmitUserFeedbackPayload): Promise<any>;
        close(): Promise<any>;
        openWebViewAlwaysOnTop(payload: import('./payload.types').OpenWebViewAlwaysOnTop): Promise<void>;
        share(payload: import('./payload.types').SharePayload): Promise<import('./payload.types').ShareResponse>;
        getThemes(payload: Partial<import('../main.lib').CanvasThemeRetrieve>): Promise<import('../main.lib').CanvasThemeRetrieve[]>;
        assignCanvasTheme(payload: {
            canvas_id: import('../main.lib').CanvasRetrieve["id"];
            theme_id: import('../main.lib').CanvasThemeRetrieve["id"];
        }): Promise<{
            canvas_id: import('../main.lib').CanvasRetrieve["id"];
            theme_id: import('../main.lib').CanvasThemeRetrieve["id"];
        }>;
        API: import('./api/LowLevelApi').LowLevelApi;
    };
    promptPia(payload: import('./api/modules/ui/types.ui').UiPromptPiaRequest): Promise<import('./api/modules/ui/types.ui').UiPromptPiaResponse>;
    completePostcall(payload: import('./api/modules/ui/types.ui').UiCompletePostcallRequest): Promise<void>;
    cancelMeeting(): Promise<void>;
    resumeMeeting(): Promise<void>;
    stopMeeting(): Promise<void>;
    enablePostcallSubmit(): Promise<void>;
    disablePostcallSubmit(): Promise<void>;
    setPostcallStyle(payload: import('./api/modules/ui/types.ui').UiSetPostcallStyleRequest): Promise<void>;
    updateCanvas(payload: import('./api/modules/ui/types.ui').UiUpdateCanvasRequest): Promise<import('../main.lib').CanvasRetrieve>;
    appLoaded(): Promise<void>;
    appResize(payload: import('./api/modules/ui/types.ui').UiAppResizeRequest): Promise<void>;
    closeCanvasSectionExecution(): Promise<void>;
    canvasNavigateNextPage(): Promise<void>;
    canvasNavigatePreviousPage(): Promise<void>;
    canvasNavigatePage(payload: import('./api/modules/ui/types.ui').UiCanvasNavigatePageRequest): Promise<void>;
    openCanvasOverlay(payload: {
        id: import('../main.lib').CanvasRetrieve["id"];
        edit_mode?: boolean;
        fullscreen?: boolean;
        component_id?: string;
        section_id?: string;
        position?: {
            left?: number | string;
            right?: number | string;
            top?: number | string;
            bottom?: number | string;
        };
    }): Promise<void>;
    selectCanvases(payload?: import('./api/modules/ui/types.ui').UiSelectCanvasesRequest): Promise<import('./api/modules/ui/types.ui').UiSelectCanvasesResponse>;
    captureAppError(payload: import('./api/modules/ui/types.ui').UiCaptureAppErrorRequest): Promise<void>;
    updateLocation(payload: import('./interfaces').UpdateLocationPitcherEvent): Promise<any>;
    embeddableReady(): Promise<void>;
    ui_select_content(payload?: import('./api/modules/ui/types.ui').UiSelectContentRequest): Promise<import('./api/modules/ui/types.ui').UiSelectContentResponse>;
    selectContent(payload?: import('./api/modules/ui/types.ui').UiSelectContentRequest): Promise<import('./api/modules/ui/types.ui').UiSelectContentResponse>;
    open(payload: import('./api/modules/ui/types.ui').UiOpenRequest): Promise<void>;
    toast(payload: import('./api/modules/ui/types.ui').UiToastRequest): Promise<void>;
    preselectSfdcMeetingId(payload: import('./api/modules/ui/types.ui').UiPreselectSfdcMeetingIdRequest): Promise<import('./api/modules/ui/types.ui').UiPreselectSfdcMeetingIdResponse>;
    selectCollectionContent(payload?: import('./api/modules/ui/types.ui').UiSelectCollectionPlayerRequest): Promise<import('./api/modules/ui/types.ui').UiSelectCollectionPlayerResponse>;
    selectAgendaContent(payload?: import('./api/modules/ui/types.ui').UiSelectAgendaRequest): Promise<import('./api/modules/ui/types.ui').UiSelectAgendaResponse>;
    on: <T extends keyof import('./api/modules/ui/types.ui').UiMessagePayloads>(type: T, handler: (data: import('./api/modules/ui/types.ui').UiMessagePayloads[T]) => Promise<void>) => Promise<() => void>;
    onMeetingCanceled: (handler: (data: import('./api/modules/ui/types.ui').UiMeetingCanceledPayload) => Promise<void>) => Promise<() => void>;
    onCanvasUpdated: (handler: (data: import('./api/modules/ui/types.ui').UiCanvasUpdatedPayload) => Promise<void>) => Promise<() => void>;
    onSectionListUpdated: (handler: (data: import('./api/modules/ui/types.ui').UiSectionListUpdatedPayload) => Promise<void>) => Promise<() => void>;
    onAppSetData: (handler: (data: import('./api/modules/ui/types.ui').UiAppSetDataPayload) => Promise<void>) => Promise<() => void>;
    onAppUpdateData: (handler: (data: import('./api/modules/ui/types.ui').UiAppUpdateDataPayload) => Promise<void>) => Promise<() => void>;
    uiBroadcast: (payload: import('./api/modules/ui/types.ui').UiBroadcastRequest) => Promise<void>;
    off: (type: string, callback: (payload: import('./interfaces').PitcherEvent) => void) => void;
    enterFullscreen: () => Promise<any>;
    exitFullscreen: () => Promise<any>;
    isFullscreen: () => Promise<any>;
    logout: () => Promise<any>;
    quitInstance: () => Promise<any>;
    getRequestTypes: () => Promise<any>;
    broadcast: (event: import('./interfaces').PitcherEvent) => Promise<any>;
    subscribe: () => Promise<any>;
    unsubscribe: () => Promise<any>;
    openExternalUrl(payload: import('./payload.types').OpenExternalUrlRequestPayload): Promise<void>;
    getEnv(): Promise<import('./interfaces').PitcherEnv>;
    updateMyUser(payload: {
        language?: import('../main.lib').LanguageEnum | undefined;
    }): Promise<import('../main.lib').User>;
    isOffline(): Promise<boolean>;
    getLanguages(): Promise<import('./api/modules').Language[]>;
    getEvents(payload: Partial<import('../main.lib').EventRequest>): Promise<import('../main.lib').PaginatedData<import('../main.lib').Event>>;
    createEvent(payload: import('../main.lib').EventRequest): Promise<import('../main.lib').Event>;
    updateEvent(payload: import('../main.lib').PatchedEventRequest): Promise<import('../main.lib').Event>;
    deleteEvent(payload: Partial<import('../main.lib').Event>): Promise<void>;
    getCanvases(payload: import('../main.lib').GetCanvasesParams & {
        filters?: Record<string, any>;
        fields?: string;
    }): Promise<import('../main.lib').PaginatedData<import('../main.lib').CanvasRetrieve>>;
    createCanvas(payload: Omit<import('../main.lib').CanvasCreateRequest, "instance_id">): Promise<import('../main.lib').CanvasRetrieve>;
    deleteCanvas(payload: {
        id: import('../main.lib').CanvasRetrieve["id"];
    }): Promise<import('../main.lib').CanvasRetrieve>;
    updateCanvasIndicators(payload: {
        indicators: Record<string, import('../main.lib').CanvasIndicator>;
        id: import('../main.lib').CanvasRetrieve["id"];
        instance_id?: import('../main.lib').Instance["id"];
    }): Promise<import('../main.lib').CanvasRetrieve>;
    getCanvas(payload: {
        id: import('../main.lib').CanvasRetrieve["id"];
        fields?: string;
    }): Promise<import('../main.lib').CanvasRetrieve>;
    shareCanvas(payload: {
        id: import('../main.lib').CanvasRetrieve["id"];
    }): Promise<import('../main.lib').SharedLink>;
    getCanvasRecommendedFiles(payload: {
        canvas_id: import('../main.lib').CanvasRetrieve["id"];
        match?: ("tags" | "metadata")[];
    }): Promise<import('../main.lib').CanvasRecommendedFiles>;
    getCanvasTheme(payload: {
        canvas_id: import('../main.lib').CanvasRetrieve["id"];
    }): Promise<import('../main.lib').CanvasThemeRetrieve>;
    unassignCanvasTheme(payload: {
        canvas_id: import('../main.lib').CanvasRetrieve["id"];
    }): Promise<void>;
    getFiles(payload: import('./payload.types').ListFilesPayload & {
        filters?: Record<string, any>;
        fields?: string;
    }): Promise<import('../main.lib').PaginatedFileList>;
    getRecentFiles(payload?: import('./payload.types').GetRecentFilesPayload): Promise<import('../main.lib').File[]>;
    downloadFile(payload: {
        file_id: import('../main.lib').File["id"];
    }): Promise<null>;
    getAppConfig(payload: {
        app_name: string;
    }): Promise<Record<string, any>>;
    getFile(payload: {
        id?: import('../main.lib').FileRetrieve["id"];
        file_id?: import('../main.lib').FileRetrieve["id"];
    }): Promise<import('../main.lib').FileRetrieve>;
    getFileRevisionData(payload: {
        file_id: import('../main.lib').FileRetrieve["id"];
        revision_id: import('../main.lib').FileRevision["id"];
    }): Promise<import('../main.lib').FileRetrieve>;
    updateFile(payload: import('../main.lib').FileUpdateRequest & {
        id: import('../main.lib').File["id"];
    }): Promise<import('../main.lib').FileRetrieve>;
    deleteFile(payload: {
        file_id: import('../main.lib').File["id"];
    }): Promise<import('../main.lib').File["id"]>;
    createFile(payload: Omit<import('../main.lib').AllFileCreateRequest, "instance_id">): Promise<import('../main.lib').FileRetrieve>;
    selectDeviceFile(): Promise<import('../main.lib').DeviceFile>;
    getFileRevisions(payload: {
        id?: import('../main.lib').FileRetrieve["id"];
        file_id?: import('../main.lib').FileRetrieve["id"];
    }): Promise<import('../main.lib').FileRevision[]>;
    search(payload: {
        query: string;
        includeExpired?: boolean;
    }): Promise<any>;
    getUsers(payload?: import('../main.lib').GetUsersParams): Promise<import('../main.lib').PaginatedData<import('../main.lib').User>>;
    refreshServiceToken(payload?: import('../main.lib').RefreshServiceTokenRequest): Promise<import('../main.lib').RefreshServiceTokenResponse>;
    refreshAccessToken(): any;
    fetchDocumentInfo(payload: {
        fileId: import('../main.lib').File["id"];
    }): Promise<{
        pageCount: number;
        [key: string]: unknown;
    }>;
    renderPageAsImage(payload: {
        fileId: import('../main.lib').File["id"];
        documentId?: import('../main.lib').File["id"];
        pageIndex: number;
        params: {
            width: number;
        } | {
            height: number;
        };
    }): Promise<ArrayBuffer>;
    query(payload: import('./payload.types').QueryPayload): Promise<any>;
    crmQuery(payload: import('./payload.types').CRMQueryPayload): Promise<any>;
    getFolders(payload: import('./payload.types').FolderListRequest): Promise<import('../main.lib').PaginatedFolderList>;
    getFolder(payload?: {
        id: import('../main.lib').FolderRetrieve["id"];
    }): Promise<import('../main.lib').FolderRetrieve>;
    createFolder(payload: Omit<import('../main.lib').FolderCreateRequest, "instance_id">): Promise<import('../main.lib').FolderRetrieve>;
    updateFolder(payload: import('../main.lib').FolderUpdateRequest & {
        id: import('../main.lib').Folder["id"];
    }): Promise<import('../main.lib').FolderRetrieve>;
    deleteFolder(payload: {
        folder_id: import('../main.lib').FolderRetrieve["id"];
    }): Promise<void>;
    moveFolderItems(payload: {
        target_folder_id: import('../main.lib').Folder["id"];
        items: {
            id: import('../main.lib').File["id"] | import('../main.lib').Folder["id"];
            type: "folder" | "file";
        }[];
    }): Promise<import('../main.lib').FolderRetrieve>;
    getCoreFolders(payload: {
        instance_id: string;
        entity: import('../main.lib').CoreFolderEntityType;
        parent_id?: string | null;
    }): Promise<import('../main.lib').CoreFolderContentsRetrieve>;
    patchCoreFolder(id: string, payload: Partial<import('../main.lib').CoreFolderRetrieve>): Promise<import('../main.lib').CoreFolderContentsRetrieve>;
    getFavorites(payload?: import('../main.lib').GetFavoritesParams): Promise<import('../main.lib').PaginatedFavoriteList>;
    createFavorite(payload: import('../main.lib').FavoriteCreateRequest): Promise<import('../main.lib').Favorite>;
    deleteFavorite(payload: {
        favorite_id: import('../main.lib').Favorite["id"];
    }): Promise<void>;
    notify(payload: import('./payload.types').NotificationPayload): Promise<void>;
    track(payload: {
        event_name: string;
        payload: any;
    }): Promise<any>;
    getInstanceMetadataTemplates(payload?: import('./payload.types').GetInstanceMetadataTemplatesPayload): Promise<import('../main.lib').PaginatedMetadataTemplateList>;
    triggerNonFilesSync(): Promise<void>;
    submitUserFeedback(payload: import('./payload.types').SubmitUserFeedbackPayload): Promise<any>;
    close(): Promise<any>;
    openWebViewAlwaysOnTop(payload: import('./payload.types').OpenWebViewAlwaysOnTop): Promise<void>;
    share(payload: import('./payload.types').SharePayload): Promise<import('./payload.types').ShareResponse>;
    getThemes(payload: Partial<import('../main.lib').CanvasThemeRetrieve>): Promise<import('../main.lib').CanvasThemeRetrieve[]>;
    assignCanvasTheme(payload: {
        canvas_id: import('../main.lib').CanvasRetrieve["id"];
        theme_id: import('../main.lib').CanvasThemeRetrieve["id"];
    }): Promise<{
        canvas_id: import('../main.lib').CanvasRetrieve["id"];
        theme_id: import('../main.lib').CanvasThemeRetrieve["id"];
    }>;
    API: import('./api/LowLevelApi').LowLevelApi;
};
